--RaidR Main File

local flasks = {}
flasks["Flask of the Whispered Pact"] = 127847
flasks["Flask of the Seventh Demon"] = 127848
flasks["Flask of the Countless Armies"] = 127849
flasks["Flask of Ten Thousand Scars"] = 127850

local potions = {}
potions["Ancient Healing Potion"] = 127834
potions["Ancient Mana Potion"] = 127835
potions["Ancient Rejuvenation Potion"] = 127836
potions["Potion of Deadly Grace"] = 127843
potions["Potion of the Old War"] = 127844
potions["Unbending Potion"] = 127845
potions["Leytorrent Potion"] = 127846
potions["Potion of Prolonged Power"] = 142117
potions["Astral Healing Potion"] = 152615

local food = {}
food["The Hungry Magister"] = 133570
food["Azshari Salad"] = 133571
food["Nightborne Delicacy Platter"] = 133572
food["Seed-Battered Fish Plate"] = 133573
food["Fishbrul Special"] = 133574

local misc = {}
misc["Spirit Cauldron"] = 127851
misc["Lavish Suramar Feast"] = 133579
misc["Defiled Augment Rune"] = 140587

local frames = {}
local scrollFrames = {}
local buttons = {}
local dropdowns = {}
local fontStrings = {}
local editBoxes = {}
local checkButtons = {}

local flaskFrameName
local flaskCountStringName
local flaskItemIconName
local flaskNameStringName

local potionFrameName
local potionCountStringName
local potionItemIconName
local potionNameStringName

local foodFrameName
local foodCountStringName
local foodItemIconName
local foodNameStringName

local miscFrameName
local miscCountStringName
local miscItemIconName
local miscNameStringName



--main frame for initial config
frames.RaidRConfig = CreateFrame("Frame", "RaidRConfigFrame", UIParent)
frames.RaidRConfig:Hide()

--main frame for reminders config
frames.RaidRReminder = CreateFrame("Frame", "RaidRReminderFrame", UIParent)
frames.RaidRReminder:Hide()

local configCreated = false
local reminderCreated = false

--Returns the day of the week
local function GetDay()
	local daysoftheweek={"Sunday","Monday","Tuesday","Wednesday","Thrusday","Friday","Saturday"}
	local day=daysoftheweek[date("*t").wday]
	return day
end

--Used for determining if today is a raid day
local today = GetDay()

--Calculates a difference in time
local function TimeDiff(hour, minute, ampm, diff)
	local flip = false
	if(diff == 60) then
		if(hour == 12) then
			flip = true
		end
		hour = hour - 1
	elseif((minute - diff) < 0) then
		if(hour == 12) then
			flip = true
		end
		hour = hour - 1
		minute = 60 + (minute - diff)
	else
		minute = minute - diff
	end
	if(flip) then
		if(ampm == "AM") then
			ampm = "PM"
		else
			ampm = "AM"
		end
	end
	if(hour == 0) then
		hour = 12
	end
	if(hour == -1) then
		hour = 11
	end
	local diffTable = {}
	diffTable["Hour"] = hour
	diffTable["Minute"] = minute
	diffTable["AMPM"] = ampm
	return diffTable
end

--Returns the number of Seals of Broken Fate the character has purchased this week
local function GetSealsCount()
	local count = 0
	for i,q in ipairs({43510,43892,43893,43894,43895,43896,43897,47864,47851,47865}) do
		if(IsQuestFlaggedCompleted(q)) then
			count = count + 1
		end
	end
	return count
end

--Runs the config window
local function RunInitialConfig()
	if(frames.RaidRReminder:IsVisible() == false and configCreated == false) then
		--Setup config frame
		frames.RaidRConfig:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.RaidRConfig:SetSize(350, 400)
		frames.RaidRConfig:SetPoint("CENTER", 500, 0)
		frames.RaidRConfig:EnableMouse(true)
		frames.RaidRConfig:SetMovable(true)
		frames.RaidRConfig:RegisterForDrag("LeftButton")
		frames.RaidRConfig:SetScript("OnDragStart", function(self) self:StartMoving() end)
		frames.RaidRConfig:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)
		frames.RaidRConfig:Show()



		--Greeting Frame
		frames.greetingFrame = CreateFrame("Frame", "GreetingFrame", frames.RaidRConfig)
		frames.greetingFrame:SetSize(350,400)
		frames.greetingFrame:SetPoint("TOPLEFT")

		--Greeting Frame: String for Initial Window
		fontStrings.greetingString = frames.greetingFrame:CreateFontString("Greeting")
		fontStrings.greetingString:SetFont("Fonts\\FRIZQT__.ttf", 24, "OUTLINE")
		fontStrings.greetingString:SetText("Welcome to RaidR!\n\nLet's get started.")
		fontStrings.greetingString:SetJustifyH("CENTER")
		fontStrings.greetingString:SetPoint("CENTER", 0, 130)

		--Greeting Frame: Next Button
		buttons.greetingFrameNextButton = CreateFrame("Button", "GreetingFrameNextButton", frames.greetingFrame, "UIPanelButtonTemplate")
		buttons.greetingFrameNextButton:SetSize(100,30)
		buttons.greetingFrameNextButton:SetPoint("CENTER")
		buttons.greetingFrameNextButton:SetText("Okay!")

		--Greeting Frame: Skip Button
		buttons.greetingFrameSkipButton = CreateFrame("Button", "GreetingFrameSkipButton", frames.greetingFrame, "UIPanelButtonTemplate")
		buttons.greetingFrameSkipButton:SetSize(100,30)
		buttons.greetingFrameSkipButton:SetPoint("CENTER", 0, -40)
		buttons.greetingFrameSkipButton:SetText("Skip for now")
		buttons.greetingFrameSkipButton:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetText("You can re-run this initial setup at any time with the chat command '/raidr config'")
			GameTooltip:Show()
		end)
		buttons.greetingFrameSkipButton:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)



		--Flask Frame
		frames.flaskFrame = CreateFrame("Frame", "FlaskFrame", frames.RaidRConfig)
		frames.flaskFrame:SetSize(350,400)
		frames.flaskFrame:SetPoint("TOPLEFT")
		frames.flaskFrame:Hide()

		--Flask Frame: String for instructions
		fontStrings.flaskString = frames.flaskFrame:CreateFontString("FlaskInstructions")
		fontStrings.flaskString:SetFont("Fonts\\FRIZQT__.ttf", 17, "OUTLINE")
		fontStrings.flaskString:SetText("Enter the number of each flask\nyou expect to use during raid")
		fontStrings.flaskString:SetJustifyH("CENTER")
		fontStrings.flaskString:SetPoint("CENTER", 0, 150)

		--Flask Frame: Frame for making a border
		frames.flaskBorderFrame = CreateFrame("Frame", "FlaskBorderFrame", frames.flaskFrame)
		frames.flaskBorderFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.flaskBorderFrame:SetPoint("TOPLEFT", 20, -80)
		frames.flaskBorderFrame:SetPoint("BOTTOMRIGHT", -40, 60)

		--Flask Frame: ScrollFrame for flask list
		scrollFrames.flaskScrollFrame = CreateFrame("ScrollFrame", "FlaskScrollFrame", frames.flaskBorderFrame, "UIPanelScrollFrameTemplate")
		scrollFrames.flaskScrollFrame:SetPoint("TOPLEFT", 0, -10)
		scrollFrames.flaskScrollFrame:SetPoint("BOTTOMRIGHT", 0, 10)
		scrollFrames.flaskScrollFrame:SetClipsChildren(true)

		--Flask Frame: Content container for flask ScrollFrame
		frames.flaskScrollContent = CreateFrame("Frame", "FlaskScrollContent", scrollFrames.flaskScrollFrame)
		frames.flaskScrollContent:SetSize(290, 230)

		--Whispered Pact Frame
		frames.whisperedPactFrame = CreateFrame("Frame", "wpFrame", frames.flaskScrollContent)
		frames.whisperedPactFrame:SetSize(290, 75)
		frames.whisperedPactFrame:SetPoint("TOPLEFT", 0, 10)
		--Whispered Pact EditBox
		editBoxes.wpEditBox = CreateFrame("EditBox", "editBoxes.wpEditBox", frames.whisperedPactFrame, "InputBoxTemplate")
		editBoxes.wpEditBox:SetAutoFocus(false)
		editBoxes.wpEditBox:SetSize(25,30)
		editBoxes.wpEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.wpEditBox:SetNumeric(true)
		editBoxes.wpEditBox:SetMaxLetters(3)
		editBoxes.wpEditBox:SetText("0")
		editBoxes.wpEditBox:SetJustifyH("LEFT")
		editBoxes.wpEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.wpEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Whispered Pact Item Icon
		buttons.wpItemIcon = CreateFrame("Button", "buttons.wpItemIcon", frames.whisperedPactFrame)
		buttons.wpItemIcon:SetSize(40,40)
		buttons.wpItemIcon:SetPoint("CENTER", -70, 0)
		buttons.wpItemIcon:SetNormalTexture(GetItemIcon(flasks["Flask of the Whispered Pact"]))
		buttons.wpItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(flasks["Flask of the Whispered Pact"])
			GameTooltip:Show()
		end)
		buttons.wpItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Whispered Pact Name
		fontStrings.wpString = frames.whisperedPactFrame:CreateFontString("wpName")
		fontStrings.wpString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.wpString:SetText("Flask of the Whispered Pact")
		fontStrings.wpString:SetJustifyH("LEFT")
		fontStrings.wpString:SetPoint("CENTER", 30, 0)

		--Seventh Demon Frame
		frames.seventhDemonFrame = CreateFrame("Frame", "sdFrame", frames.flaskScrollContent)
		frames.seventhDemonFrame:SetSize(290, 75)
		frames.seventhDemonFrame:SetPoint("TOPLEFT", 0, -45)
		--Seventh Demon EditBox
		editBoxes.sdEditBox = CreateFrame("EditBox", "editBoxes.sdEditBox", frames.seventhDemonFrame, "InputBoxTemplate")
		editBoxes.sdEditBox:SetAutoFocus(false)
		editBoxes.sdEditBox:SetSize(25,30)
		editBoxes.sdEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.sdEditBox:SetNumeric(true)
		editBoxes.sdEditBox:SetMaxLetters(3)
		editBoxes.sdEditBox:SetText("0")
		editBoxes.sdEditBox:SetJustifyH("LEFT")
		editBoxes.sdEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.sdEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Seventh Demon Item Icon
		buttons.sdItemIcon = CreateFrame("Button", "buttons.sdItemIcon", frames.seventhDemonFrame)
		buttons.sdItemIcon:SetSize(40,40)
		buttons.sdItemIcon:SetPoint("CENTER", -70, 0)
		buttons.sdItemIcon:SetNormalTexture(GetItemIcon(flasks["Flask of the Seventh Demon"]))
		buttons.sdItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(flasks["Flask of the Seventh Demon"])
			GameTooltip:Show()
		end)
		buttons.sdItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Seventh Demon Name
		fontStrings.sdString = frames.seventhDemonFrame:CreateFontString("sdName")
		fontStrings.sdString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.sdString:SetText("Flask of the Seventh Demon")
		fontStrings.sdString:SetJustifyH("LEFT")
		fontStrings.sdString:SetPoint("CENTER", 30, 0)

		--Countless Armies Frame
		frames.countlessArmiesFrame = CreateFrame("Frame", "caFrame", frames.flaskScrollContent)
		frames.countlessArmiesFrame:SetSize(290, 75)
		frames.countlessArmiesFrame:SetPoint("TOPLEFT", 0, -100)
		--Countless Armies EditBox
		editBoxes.caEditBox = CreateFrame("EditBox", "editBoxes.caEditBox", frames.countlessArmiesFrame, "InputBoxTemplate")
		editBoxes.caEditBox:SetAutoFocus(false)
		editBoxes.caEditBox:SetSize(25,30)
		editBoxes.caEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.caEditBox:SetNumeric(true)
		editBoxes.caEditBox:SetMaxLetters(3)
		editBoxes.caEditBox:SetText("0")
		editBoxes.caEditBox:SetJustifyH("LEFT")
		editBoxes.caEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.caEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Countless Armies Item Icon
		buttons.caItemIcon = CreateFrame("Button", "buttons.caItemIcon", frames.countlessArmiesFrame)
		buttons.caItemIcon:SetSize(40,40)
		buttons.caItemIcon:SetPoint("CENTER", -70, 0)
		buttons.caItemIcon:SetNormalTexture(GetItemIcon(flasks["Flask of the Countless Armies"]))
		buttons.caItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(flasks["Flask of the Countless Armies"])
			GameTooltip:Show()
		end)
		buttons.caItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Countless Armies Name
		fontStrings.caString = frames.countlessArmiesFrame:CreateFontString("caName")
		fontStrings.caString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.caString:SetText("Flask of the Countless Armies")
		fontStrings.caString:SetJustifyH("LEFT")
		fontStrings.caString:SetPoint("CENTER", 30, 0)

		--Ten Thousand Scars Frame
		frames.tenThousandScarsFrame = CreateFrame("Frame", "ttsFrame", frames.flaskScrollContent)
		frames.tenThousandScarsFrame:SetSize(290, 75)
		frames.tenThousandScarsFrame:SetPoint("TOPLEFT", 0, -155)
		--Ten Thousand Scars EditBox
		editBoxes.ttsEditBox = CreateFrame("EditBox", "editBoxes.ttsEditBox", frames.tenThousandScarsFrame, "InputBoxTemplate")
		editBoxes.ttsEditBox:SetAutoFocus(false)
		editBoxes.ttsEditBox:SetSize(25,30)
		editBoxes.ttsEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.ttsEditBox:SetNumeric(true)
		editBoxes.ttsEditBox:SetMaxLetters(3)
		editBoxes.ttsEditBox:SetText("0")
		editBoxes.ttsEditBox:SetJustifyH("LEFT")
		editBoxes.ttsEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.ttsEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Ten Thousand Scars Item Icon
		buttons.ttsItemIcon = CreateFrame("Button", "buttons.ttsItemIcon", frames.tenThousandScarsFrame)
		buttons.ttsItemIcon:SetSize(40,40)
		buttons.ttsItemIcon:SetPoint("CENTER", -70, 0)
		buttons.ttsItemIcon:SetNormalTexture(GetItemIcon(flasks["Flask of Ten Thousand Scars"]))
		buttons.ttsItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(flasks["Flask of Ten Thousand Scars"])
			GameTooltip:Show()
		end)
		buttons.ttsItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Ten Thousand Scars Name
		fontStrings.ttsString = frames.tenThousandScarsFrame:CreateFontString("caName")
		fontStrings.ttsString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.ttsString:SetText("Flask of Ten Thousand Scars")
		fontStrings.ttsString:SetJustifyH("LEFT")
		fontStrings.ttsString:SetPoint("CENTER", 30, 0)

		scrollFrames.flaskScrollFrame:SetScrollChild(frames.flaskScrollContent)

		--Flask Frame: Previous Button
		buttons.flaskFramePreviousButton = CreateFrame("Button", "FlaskFramePreviousButton", frames.flaskFrame, "UIPanelButtonTemplate")
		buttons.flaskFramePreviousButton:SetSize(100,30)
		buttons.flaskFramePreviousButton:SetPoint("CENTER", -100, -165)
		buttons.flaskFramePreviousButton:SetText("Previous")

		--Flask Frame: Next Button
		buttons.flaskFrameNextButton = CreateFrame("Button", "FlaskFrameNextButton", frames.flaskFrame, "UIPanelButtonTemplate")
		buttons.flaskFrameNextButton:SetSize(100,30)
		buttons.flaskFrameNextButton:SetPoint("CENTER", 100, -165)
		buttons.flaskFrameNextButton:SetText("Next")



		--Potion Frame
		frames.potionFrame = CreateFrame("Frame", "PotionFrame", frames.RaidRConfig)
		frames.potionFrame:SetSize(350,400)
		frames.potionFrame:SetPoint("TOPLEFT")
		frames.potionFrame:Hide()

		--Potion Frame: String for instructions
		fontStrings.potionString = frames.potionFrame:CreateFontString("PotionInstructions")
		fontStrings.potionString:SetFont("Fonts\\FRIZQT__.ttf", 17, "OUTLINE")
		fontStrings.potionString:SetText("Enter the number of each potion\nyou expect to use during raid")
		fontStrings.potionString:SetJustifyH("CENTER")
		fontStrings.potionString:SetPoint("CENTER", 0, 150)

		--Potion Frame: Frame for making a border
		frames.potionBorderFrame = CreateFrame("Frame", "PotionBorderFrame", frames.potionFrame)
		frames.potionBorderFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.potionBorderFrame:SetPoint("TOPLEFT", 20, -80)
		frames.potionBorderFrame:SetPoint("BOTTOMRIGHT", -40, 60)

		--Potion Frame: ScrollFrame for potion list
		scrollFrames.potionScrollFrame = CreateFrame("ScrollFrame", "PotionScrollFrame", frames.potionBorderFrame, "UIPanelScrollFrameTemplate")
		scrollFrames.potionScrollFrame:SetPoint("TOPLEFT", 0, -10)
		scrollFrames.potionScrollFrame:SetPoint("BOTTOMRIGHT", 0, 10)
		scrollFrames.potionScrollFrame:SetClipsChildren(true)

		--Potion Frame: Content container for potion ScrollFrame
		frames.potionScrollContent = CreateFrame("Frame", "PotionScrollContent", scrollFrames.potionScrollFrame)
		frames.potionScrollContent:SetSize(290, 450)

		--Ancient Healing Potion Frame
		frames.ancientHealingPotionFrame = CreateFrame("Frame", "anhpFrame", frames.potionScrollContent)
		frames.ancientHealingPotionFrame:SetSize(290, 75)
		frames.ancientHealingPotionFrame:SetPoint("TOPLEFT", 0, 10)
		--Ancient Healing Potion EditBox
		editBoxes.anhpEditBox = CreateFrame("EditBox", "editBoxes.anhpEditBox", frames.ancientHealingPotionFrame, "InputBoxTemplate")
		editBoxes.anhpEditBox:SetAutoFocus(false)
		editBoxes.anhpEditBox:SetSize(25,30)
		editBoxes.anhpEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.anhpEditBox:SetNumeric(true)
		editBoxes.anhpEditBox:SetMaxLetters(3)
		editBoxes.anhpEditBox:SetText("0")
		editBoxes.anhpEditBox:SetJustifyH("LEFT")
		editBoxes.anhpEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.anhpEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Ancient Healing Potion Item Icon
		buttons.anhpItemIcon = CreateFrame("Button", "buttons.anhpItemIcon", frames.ancientHealingPotionFrame)
		buttons.anhpItemIcon:SetSize(40,40)
		buttons.anhpItemIcon:SetPoint("CENTER", -70, 0)
		buttons.anhpItemIcon:SetNormalTexture(GetItemIcon(potions["Ancient Healing Potion"]))
		buttons.anhpItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(potions["Ancient Healing Potion"])
			GameTooltip:Show()
		end)
		buttons.anhpItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Ancient Healing Potion Name
		fontStrings.anhpString = frames.ancientHealingPotionFrame:CreateFontString("anhpName")
		fontStrings.anhpString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.anhpString:SetText("Ancient Healing Potion")
		fontStrings.anhpString:SetJustifyH("LEFT")
		fontStrings.anhpString:SetPoint("CENTER", 30, 0)

		--Ancient Mana Potion Frame
		frames.ancientManaPotionFrame = CreateFrame("Frame", "ampFrame", frames.potionScrollContent)
		frames.ancientManaPotionFrame:SetSize(290, 75)
		frames.ancientManaPotionFrame:SetPoint("TOPLEFT", 0, -45)
		--Ancient Mana Potion EditBox
		editBoxes.ampEditBox = CreateFrame("EditBox", "editBoxes.ampEditBox", frames.ancientManaPotionFrame, "InputBoxTemplate")
		editBoxes.ampEditBox:SetAutoFocus(false)
		editBoxes.ampEditBox:SetSize(25,30)
		editBoxes.ampEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.ampEditBox:SetNumeric(true)
		editBoxes.ampEditBox:SetMaxLetters(3)
		editBoxes.ampEditBox:SetText("0")
		editBoxes.ampEditBox:SetJustifyH("LEFT")
		editBoxes.ampEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.ampEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Ancient Mana Potion Item Icon
		buttons.ampItemIcon = CreateFrame("Button", "buttons.ampItemIcon", frames.ancientManaPotionFrame)
		buttons.ampItemIcon:SetSize(40,40)
		buttons.ampItemIcon:SetPoint("CENTER", -70, 0)
		buttons.ampItemIcon:SetNormalTexture(GetItemIcon(potions["Ancient Mana Potion"]))
		buttons.ampItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(potions["Ancient Mana Potion"])
			GameTooltip:Show()
		end)
		buttons.ampItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Ancient Mana Potion Name
		fontStrings.ampString = frames.ancientManaPotionFrame:CreateFontString("ampName")
		fontStrings.ampString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.ampString:SetText("Ancient Mana Potion")
		fontStrings.ampString:SetJustifyH("LEFT")
		fontStrings.ampString:SetPoint("CENTER", 30, 0)

		--Ancient Rejuvenation Potion Frame
		frames.ancientRejuvenationPotionFrame = CreateFrame("Frame", "ajpFrame", frames.potionScrollContent)
		frames.ancientRejuvenationPotionFrame:SetSize(290, 75)
		frames.ancientRejuvenationPotionFrame:SetPoint("TOPLEFT", 0, -100)
		--Ancient Rejuvenation Potion EditBox
		editBoxes.ajpEditBox = CreateFrame("EditBox", "editBoxes.ajpEditBox", frames.ancientRejuvenationPotionFrame, "InputBoxTemplate")
		editBoxes.ajpEditBox:SetAutoFocus(false)
		editBoxes.ajpEditBox:SetSize(25,30)
		editBoxes.ajpEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.ajpEditBox:SetNumeric(true)
		editBoxes.ajpEditBox:SetMaxLetters(3)
		editBoxes.ajpEditBox:SetText("0")
		editBoxes.ajpEditBox:SetJustifyH("LEFT")
		editBoxes.ajpEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.ajpEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Ancient Rejuvenation Potion Item Icon
		buttons.ajpItemIcon = CreateFrame("Button", "buttons.ajpItemIcon", frames.ancientRejuvenationPotionFrame)
		buttons.ajpItemIcon:SetSize(40,40)
		buttons.ajpItemIcon:SetPoint("CENTER", -70, 0)
		buttons.ajpItemIcon:SetNormalTexture(GetItemIcon(potions["Ancient Rejuvenation Potion"]))
		buttons.ajpItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(potions["Ancient Rejuvenation Potion"])
			GameTooltip:Show()
		end)
		buttons.ajpItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Ancient Rejuvenation Potion Name
		fontStrings.ajpString = frames.ancientRejuvenationPotionFrame:CreateFontString("ajpName")
		fontStrings.ajpString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.ajpString:SetText("Ancient Rejuvenation Potion")
		fontStrings.ajpString:SetJustifyH("LEFT")
		fontStrings.ajpString:SetPoint("CENTER", 30, 0)

		--Potion of Deadly Grace Frame
		frames.potionOfDeadlyGraceFrame = CreateFrame("Frame", "podgFrame", frames.potionScrollContent)
		frames.potionOfDeadlyGraceFrame:SetSize(290, 75)
		frames.potionOfDeadlyGraceFrame:SetPoint("TOPLEFT", 0, -155)
		--Potion of Deadly Grace EditBox
		editBoxes.podgEditBox = CreateFrame("EditBox", "editBoxes.podgEditBox", frames.potionOfDeadlyGraceFrame, "InputBoxTemplate")
		editBoxes.podgEditBox:SetAutoFocus(false)
		editBoxes.podgEditBox:SetSize(25,30)
		editBoxes.podgEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.podgEditBox:SetNumeric(true)
		editBoxes.podgEditBox:SetMaxLetters(3)
		editBoxes.podgEditBox:SetText("0")
		editBoxes.podgEditBox:SetJustifyH("LEFT")
		editBoxes.podgEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.podgEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Potion of Deadly Grace Item Icon
		buttons.podgItemIcon = CreateFrame("Button", "buttons.podgItemIcon", frames.potionOfDeadlyGraceFrame)
		buttons.podgItemIcon:SetSize(40,40)
		buttons.podgItemIcon:SetPoint("CENTER", -70, 0)
		buttons.podgItemIcon:SetNormalTexture(GetItemIcon(potions["Potion of Deadly Grace"]))
		buttons.podgItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(potions["Potion of Deadly Grace"])
			GameTooltip:Show()
		end)
		buttons.podgItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Potion of Deadly Grace Name
		fontStrings.podgString = frames.potionOfDeadlyGraceFrame:CreateFontString("podgName")
		fontStrings.podgString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.podgString:SetText("Potion of Deadly Grace")
		fontStrings.podgString:SetJustifyH("LEFT")
		fontStrings.podgString:SetPoint("CENTER", 30, 0)

		--Potion of the Old War Frame
		frames.potionOfTheOldWarFrame = CreateFrame("Frame", "potowFrame", frames.potionScrollContent)
		frames.potionOfTheOldWarFrame:SetSize(290, 75)
		frames.potionOfTheOldWarFrame:SetPoint("TOPLEFT", 0, -210)
		--Potion of the Old War EditBox
		editBoxes.potowEditBox = CreateFrame("EditBox", "editBoxes.potowEditBox", frames.potionOfTheOldWarFrame, "InputBoxTemplate")
		editBoxes.potowEditBox:SetAutoFocus(false)
		editBoxes.potowEditBox:SetSize(25,30)
		editBoxes.potowEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.potowEditBox:SetNumeric(true)
		editBoxes.potowEditBox:SetMaxLetters(3)
		editBoxes.potowEditBox:SetText("0")
		editBoxes.potowEditBox:SetJustifyH("LEFT")
		editBoxes.potowEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.potowEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Potion of the Old War Item Icon
		buttons.potowItemIcon = CreateFrame("Button", "buttons.potowItemIcon", frames.potionOfTheOldWarFrame)
		buttons.potowItemIcon:SetSize(40,40)
		buttons.potowItemIcon:SetPoint("CENTER", -70, 0)
		buttons.potowItemIcon:SetNormalTexture(GetItemIcon(potions["Potion of the Old War"]))
		buttons.potowItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(potions["Potion of the Old War"])
			GameTooltip:Show()
		end)
		buttons.potowItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Potion of the Old War Name
		fontStrings.potowString = frames.potionOfTheOldWarFrame:CreateFontString("potowName")
		fontStrings.potowString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.potowString:SetText("Potion of the Old War")
		fontStrings.potowString:SetJustifyH("LEFT")
		fontStrings.potowString:SetPoint("CENTER", 30, 0)

		--Unbending Potion Frame
		frames.unbendingPotionFrame = CreateFrame("Frame", "upFrame", frames.potionScrollContent)
		frames.unbendingPotionFrame:SetSize(290, 75)
		frames.unbendingPotionFrame:SetPoint("TOPLEFT", 0, -265)
		--Unbending Potion EditBox
		editBoxes.upEditBox = CreateFrame("EditBox", "editBoxes.upEditBox", frames.unbendingPotionFrame, "InputBoxTemplate")
		editBoxes.upEditBox:SetAutoFocus(false)
		editBoxes.upEditBox:SetSize(25,30)
		editBoxes.upEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.upEditBox:SetNumeric(true)
		editBoxes.upEditBox:SetMaxLetters(3)
		editBoxes.upEditBox:SetText("0")
		editBoxes.upEditBox:SetJustifyH("LEFT")
		editBoxes.upEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.upEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Unbending Potion Item Icon
		buttons.upItemIcon = CreateFrame("Button", "buttons.upItemIcon", frames.unbendingPotionFrame)
		buttons.upItemIcon:SetSize(40,40)
		buttons.upItemIcon:SetPoint("CENTER", -70, 0)
		buttons.upItemIcon:SetNormalTexture(GetItemIcon(potions["Unbending Potion"]))
		buttons.upItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(potions["Unbending Potion"])
			GameTooltip:Show()
		end)
		buttons.upItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Unbending Potion Name
		fontStrings.upString = frames.unbendingPotionFrame:CreateFontString("upName")
		fontStrings.upString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.upString:SetText("Unbending Potion")
		fontStrings.upString:SetJustifyH("LEFT")
		fontStrings.upString:SetPoint("CENTER", 30, 0)

		--Leytorrent Potion Frame
		frames.leytorrentPotionFrame = CreateFrame("Frame", "lpFrame", frames.potionScrollContent)
		frames.leytorrentPotionFrame:SetSize(290, 75)
		frames.leytorrentPotionFrame:SetPoint("TOPLEFT", 0, -320)
		--Leytorrent Potion EditBox
		editBoxes.lpEditBox = CreateFrame("EditBox", "editBoxes.lpEditBox", frames.leytorrentPotionFrame, "InputBoxTemplate")
		editBoxes.lpEditBox:SetAutoFocus(false)
		editBoxes.lpEditBox:SetSize(25,30)
		editBoxes.lpEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.lpEditBox:SetNumeric(true)
		editBoxes.lpEditBox:SetMaxLetters(3)
		editBoxes.lpEditBox:SetText("0")
		editBoxes.lpEditBox:SetJustifyH("LEFT")
		editBoxes.lpEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.lpEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Leytorrent Potion Item Icon
		buttons.lpItemIcon = CreateFrame("Button", "buttons.lpItemIcon", frames.leytorrentPotionFrame)
		buttons.lpItemIcon:SetSize(40,40)
		buttons.lpItemIcon:SetPoint("CENTER", -70, 0)
		buttons.lpItemIcon:SetNormalTexture(GetItemIcon(potions["Leytorrent Potion"]))
		buttons.lpItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(potions["Leytorrent Potion"])
			GameTooltip:Show()
		end)
		buttons.lpItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Leytorrent Potion Name
		fontStrings.lpString = frames.leytorrentPotionFrame:CreateFontString("lpName")
		fontStrings.lpString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.lpString:SetText("Leytorrent Potion")
		fontStrings.lpString:SetJustifyH("LEFT")
		fontStrings.lpString:SetPoint("CENTER", 30, 0)

		--Potion of Prolonged Power Frame
		frames.potionOfProlongedPowerFrame = CreateFrame("Frame", "poppFrame", frames.potionScrollContent)
		frames.potionOfProlongedPowerFrame:SetSize(290, 75)
		frames.potionOfProlongedPowerFrame:SetPoint("TOPLEFT", 0, -375)
		--Potion of Prolonged Power EditBox
		editBoxes.poppEditBox = CreateFrame("EditBox", "editBoxes.poppEditBox", frames.potionOfProlongedPowerFrame, "InputBoxTemplate")
		editBoxes.poppEditBox:SetAutoFocus(false)
		editBoxes.poppEditBox:SetSize(25,30)
		editBoxes.poppEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.poppEditBox:SetNumeric(true)
		editBoxes.poppEditBox:SetMaxLetters(3)
		editBoxes.poppEditBox:SetText("0")
		editBoxes.poppEditBox:SetJustifyH("LEFT")
		editBoxes.poppEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.poppEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Potion of Prolonged Power Item Icon
		buttons.poppItemIcon = CreateFrame("Button", "buttons.poppItemIcon", frames.potionOfProlongedPowerFrame)
		buttons.poppItemIcon:SetSize(40,40)
		buttons.poppItemIcon:SetPoint("CENTER", -70, 0)
		buttons.poppItemIcon:SetNormalTexture(GetItemIcon(potions["Potion of Prolonged Power"]))
		buttons.poppItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(potions["Potion of Prolonged Power"])
			GameTooltip:Show()
		end)
		buttons.poppItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Potion of Prolonged Power Name
		fontStrings.poppString = frames.potionOfProlongedPowerFrame:CreateFontString("poppName")
		fontStrings.poppString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.poppString:SetText("Potion of Prolonged Power")
		fontStrings.poppString:SetJustifyH("LEFT")
		fontStrings.poppString:SetPoint("CENTER", 30, 0)

		--Astral Healing Potion Frame
		frames.astralHealingPotionFrame = CreateFrame("Frame", "ashpFrame", frames.potionScrollContent)
		frames.astralHealingPotionFrame:SetSize(290, 75)
		frames.astralHealingPotionFrame:SetPoint("TOPLEFT", 0, -430)
		--Astral Healing Potion EditBox
		editBoxes.ashpEditBox = CreateFrame("EditBox", "editBoxes.ashpEditBox", frames.astralHealingPotionFrame, "InputBoxTemplate")
		editBoxes.ashpEditBox:SetAutoFocus(false)
		editBoxes.ashpEditBox:SetSize(25,30)
		editBoxes.ashpEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.ashpEditBox:SetNumeric(true)
		editBoxes.ashpEditBox:SetMaxLetters(3)
		editBoxes.ashpEditBox:SetText("0")
		editBoxes.ashpEditBox:SetJustifyH("LEFT")
		editBoxes.ashpEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.ashpEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Astral Healing Potion Item Icon
		buttons.ashpItemIcon = CreateFrame("Button", "buttons.ashpItemIcon", frames.astralHealingPotionFrame)
		buttons.ashpItemIcon:SetSize(40,40)
		buttons.ashpItemIcon:SetPoint("CENTER", -70, 0)
		buttons.ashpItemIcon:SetNormalTexture(GetItemIcon(potions["Astral Healing Potion"]))
		buttons.ashpItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(potions["Astral Healing Potion"])
			GameTooltip:Show()
		end)
		buttons.ashpItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Astral Healing Potion Name
		fontStrings.ashpString = frames.astralHealingPotionFrame:CreateFontString("ashpName")
		fontStrings.ashpString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.ashpString:SetText("Astral Healing Potion")
		fontStrings.ashpString:SetJustifyH("LEFT")
		fontStrings.ashpString:SetPoint("CENTER", 30, 0)

		scrollFrames.potionScrollFrame:SetScrollChild(frames.potionScrollContent)

		--Potion Frame: Previous Button
		buttons.potionFramePreviousButton = CreateFrame("Button", "PotionFramePreviousButton", frames.potionFrame, "UIPanelButtonTemplate")
		buttons.potionFramePreviousButton:SetSize(100,30)
		buttons.potionFramePreviousButton:SetPoint("CENTER", -100, -165)
		buttons.potionFramePreviousButton:SetText("Previous")

		--Potion Frame: Next Button
		buttons.potionFrameNextButton = CreateFrame("Button", "PotionFrameNextButton", frames.potionFrame, "UIPanelButtonTemplate")
		buttons.potionFrameNextButton:SetSize(100,30)
		buttons.potionFrameNextButton:SetPoint("CENTER", 100, -165)
		buttons.potionFrameNextButton:SetText("Next")



		--Food Frame
		frames.foodFrame = CreateFrame("Frame", "FoodFrame", frames.RaidRConfig)
		frames.foodFrame:SetSize(350,400)
		frames.foodFrame:SetPoint("TOPLEFT")
		frames.foodFrame:Hide()

		--Food Frame: String for instructions
		fontStrings.foodString = frames.foodFrame:CreateFontString("FoodInstructions")
		fontStrings.foodString:SetFont("Fonts\\FRIZQT__.ttf", 17, "OUTLINE")
		fontStrings.foodString:SetText("Enter the number of each food\nyou expect to use during raid")
		fontStrings.foodString:SetJustifyH("CENTER")
		fontStrings.foodString:SetPoint("CENTER", 0, 150)

		--Food Frame: Frame for making a border
		frames.foodBorderFrame = CreateFrame("Frame", "FoodBorderFrame", frames.foodFrame)
		frames.foodBorderFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.foodBorderFrame:SetPoint("TOPLEFT", 20, -80)
		frames.foodBorderFrame:SetPoint("BOTTOMRIGHT", -40, 60)

		--Food Frame: ScrollFrame for food list
		scrollFrames.foodScrollFrame = CreateFrame("ScrollFrame", "FoodScrollFrame", frames.foodBorderFrame, "UIPanelScrollFrameTemplate")
		scrollFrames.foodScrollFrame:SetPoint("TOPLEFT", 0, -10)
		scrollFrames.foodScrollFrame:SetPoint("BOTTOMRIGHT", 0, 10)
		scrollFrames.foodScrollFrame:SetClipsChildren(true)

		--Food Frame: Content container for food ScrollFrame
		frames.foodScrollContent = CreateFrame("Frame", "FoodScrollContent", scrollFrames.foodScrollFrame)
		frames.foodScrollContent:SetSize(290, 220)

		--The Hungry Magister Frame
		frames.theHungryMagisterFrame = CreateFrame("Frame", "thmFrame", frames.foodScrollContent)
		frames.theHungryMagisterFrame:SetSize(290, 75)
		frames.theHungryMagisterFrame:SetPoint("TOPLEFT", 0, 10)
		--The Hungry Magister EditBox
		editBoxes.thmEditBox = CreateFrame("EditBox", "editBoxes.thmEditBox", frames.theHungryMagisterFrame, "InputBoxTemplate")
		editBoxes.thmEditBox:SetAutoFocus(false)
		editBoxes.thmEditBox:SetSize(25,30)
		editBoxes.thmEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.thmEditBox:SetNumeric(true)
		editBoxes.thmEditBox:SetMaxLetters(3)
		editBoxes.thmEditBox:SetText("0")
		editBoxes.thmEditBox:SetJustifyH("LEFT")
		editBoxes.thmEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.thmEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--The Hungry Magister Item Icon
		buttons.thmItemIcon = CreateFrame("Button", "buttons.thmItemIcon", frames.theHungryMagisterFrame)
		buttons.thmItemIcon:SetSize(40,40)
		buttons.thmItemIcon:SetPoint("CENTER", -70, 0)
		buttons.thmItemIcon:SetNormalTexture(GetItemIcon(food["The Hungry Magister"]))
		buttons.thmItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(food["The Hungry Magister"])
			GameTooltip:Show()
		end)
		buttons.thmItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--The Hungry Magister Name
		fontStrings.thmString = frames.theHungryMagisterFrame:CreateFontString("thmName")
		fontStrings.thmString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.thmString:SetText("The Hungry Magister")
		fontStrings.thmString:SetJustifyH("LEFT")
		fontStrings.thmString:SetPoint("CENTER", 30, 0)

		--Azshari Salad Frame
		frames.azshariSaladFrame = CreateFrame("Frame", "azsFrame", frames.foodScrollContent)
		frames.azshariSaladFrame:SetSize(290, 75)
		frames.azshariSaladFrame:SetPoint("TOPLEFT", 0, -45)
		--Azshari Salad EditBox
		editBoxes.azsEditBox = CreateFrame("EditBox", "editBoxes.azsEditBox", frames.azshariSaladFrame, "InputBoxTemplate")
		editBoxes.azsEditBox:SetAutoFocus(false)
		editBoxes.azsEditBox:SetSize(25,30)
		editBoxes.azsEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.azsEditBox:SetNumeric(true)
		editBoxes.azsEditBox:SetMaxLetters(3)
		editBoxes.azsEditBox:SetText("0")
		editBoxes.azsEditBox:SetJustifyH("LEFT")
		editBoxes.azsEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.azsEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Azshari Salad Item Icon
		buttons.azsItemIcon = CreateFrame("Button", "buttons.azsItemIcon", frames.azshariSaladFrame)
		buttons.azsItemIcon:SetSize(40,40)
		buttons.azsItemIcon:SetPoint("CENTER", -70, 0)
		buttons.azsItemIcon:SetNormalTexture(GetItemIcon(food["Azshari Salad"]))
		buttons.azsItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(food["Azshari Salad"])
			GameTooltip:Show()
		end)
		buttons.azsItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Azshari Salad Name
		fontStrings.azsString = frames.azshariSaladFrame:CreateFontString("azsName")
		fontStrings.azsString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.azsString:SetText("Azshari Salad")
		fontStrings.azsString:SetJustifyH("LEFT")
		fontStrings.azsString:SetPoint("CENTER", 30, 0)

		--Nightborne Delicacy Platter Frame
		frames.nightborneDelicacyPlatterFrame = CreateFrame("Frame", "ndpFrame", frames.foodScrollContent)
		frames.nightborneDelicacyPlatterFrame:SetSize(290, 75)
		frames.nightborneDelicacyPlatterFrame:SetPoint("TOPLEFT", 0, -100)
		--Nightborne Delicacy Platter EditBox
		editBoxes.ndpEditBox = CreateFrame("EditBox", "editBoxes.ndpEditBox", frames.nightborneDelicacyPlatterFrame, "InputBoxTemplate")
		editBoxes.ndpEditBox:SetAutoFocus(false)
		editBoxes.ndpEditBox:SetSize(25,30)
		editBoxes.ndpEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.ndpEditBox:SetNumeric(true)
		editBoxes.ndpEditBox:SetMaxLetters(3)
		editBoxes.ndpEditBox:SetText("0")
		editBoxes.ndpEditBox:SetJustifyH("LEFT")
		editBoxes.ndpEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.ndpEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Nightborne Delicacy Platter Item Icon
		buttons.ndpItemIcon = CreateFrame("Button", "buttons.ndpItemIcon", frames.nightborneDelicacyPlatterFrame)
		buttons.ndpItemIcon:SetSize(40,40)
		buttons.ndpItemIcon:SetPoint("CENTER", -70, 0)
		buttons.ndpItemIcon:SetNormalTexture(GetItemIcon(food["Nightborne Delicacy Platter"]))
		buttons.ndpItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(food["Nightborne Delicacy Platter"])
			GameTooltip:Show()
		end)
		buttons.ndpItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Nightborne Delicacy Platter Name
		fontStrings.ndpString = frames.nightborneDelicacyPlatterFrame:CreateFontString("azsName")
		fontStrings.ndpString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.ndpString:SetText("Nightborne Delicacy Platter")
		fontStrings.ndpString:SetJustifyH("LEFT")
		fontStrings.ndpString:SetPoint("CENTER", 30, 0)

		--Seed-Battered Fish Plate Frame
		frames.seedBatteredFishPlateFrame = CreateFrame("Frame", "sbfpFrame", frames.foodScrollContent)
		frames.seedBatteredFishPlateFrame:SetSize(290, 75)
		frames.seedBatteredFishPlateFrame:SetPoint("TOPLEFT", 0, -155)
		--Seed-Battered Fish Plate EditBox
		editBoxes.sbfpEditBox = CreateFrame("EditBox", "editBoxes.sbfpEditBox", frames.seedBatteredFishPlateFrame, "InputBoxTemplate")
		editBoxes.sbfpEditBox:SetAutoFocus(false)
		editBoxes.sbfpEditBox:SetSize(25,30)
		editBoxes.sbfpEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.sbfpEditBox:SetNumeric(true)
		editBoxes.sbfpEditBox:SetMaxLetters(3)
		editBoxes.sbfpEditBox:SetText("0")
		editBoxes.sbfpEditBox:SetJustifyH("LEFT")
		editBoxes.sbfpEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.sbfpEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Seed-Battered Fish Plate Item Icon
		buttons.sbfpItemIcon = CreateFrame("Button", "buttons.sbfpItemIcon", frames.seedBatteredFishPlateFrame)
		buttons.sbfpItemIcon:SetSize(40,40)
		buttons.sbfpItemIcon:SetPoint("CENTER", -70, 0)
		buttons.sbfpItemIcon:SetNormalTexture(GetItemIcon(food["Seed-Battered Fish Plate"]))
		buttons.sbfpItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(food["Seed-Battered Fish Plate"])
			GameTooltip:Show()
		end)
		buttons.sbfpItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Seed-Battered Fish Plate Name
		fontStrings.sbfpString = frames.seedBatteredFishPlateFrame:CreateFontString("azsName")
		fontStrings.sbfpString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.sbfpString:SetText("Seed-Battered Fish Plate")
		fontStrings.sbfpString:SetJustifyH("LEFT")
		fontStrings.sbfpString:SetPoint("CENTER", 30, 0)

		--Fishbrul Special Frame
		frames.fishbrulSpecialFrame = CreateFrame("Frame", "fbsFrame", frames.foodScrollContent)
		frames.fishbrulSpecialFrame:SetSize(290, 75)
		frames.fishbrulSpecialFrame:SetPoint("TOPLEFT", 0, -210)
		--Fishbrul Special EditBox
		editBoxes.fbsEditBox = CreateFrame("EditBox", "editBoxes.fbsEditBox", frames.fishbrulSpecialFrame, "InputBoxTemplate")
		editBoxes.fbsEditBox:SetAutoFocus(false)
		editBoxes.fbsEditBox:SetSize(25,30)
		editBoxes.fbsEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.fbsEditBox:SetNumeric(true)
		editBoxes.fbsEditBox:SetMaxLetters(3)
		editBoxes.fbsEditBox:SetText("0")
		editBoxes.fbsEditBox:SetJustifyH("LEFT")
		editBoxes.fbsEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.fbsEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Fishbrul Special Item Icon
		buttons.fbsItemIcon = CreateFrame("Button", "buttons.fbsItemIcon", frames.fishbrulSpecialFrame)
		buttons.fbsItemIcon:SetSize(40,40)
		buttons.fbsItemIcon:SetPoint("CENTER", -70, 0)
		buttons.fbsItemIcon:SetNormalTexture(GetItemIcon(food["Fishbrul Special"]))
		buttons.fbsItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(food["Fishbrul Special"])
			GameTooltip:Show()
		end)
		buttons.fbsItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Fishbrul Special Name
		fontStrings.fbsString = frames.fishbrulSpecialFrame:CreateFontString("azsName")
		fontStrings.fbsString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.fbsString:SetText("Fishbrul Special")
		fontStrings.fbsString:SetJustifyH("LEFT")
		fontStrings.fbsString:SetPoint("CENTER", 30, 0)

		scrollFrames.foodScrollFrame:SetScrollChild(frames.foodScrollContent)

		--Food Frame: Previous Button
		buttons.foodFramePreviousButton = CreateFrame("Button", "FoodFramePreviousButton", frames.foodFrame, "UIPanelButtonTemplate")
		buttons.foodFramePreviousButton:SetSize(100,30)
		buttons.foodFramePreviousButton:SetPoint("CENTER", -100, -165)
		buttons.foodFramePreviousButton:SetText("Previous")

		--Food Frame: Next Button
		buttons.foodFrameNextButton = CreateFrame("Button", "FoodFrameNextButton", frames.foodFrame, "UIPanelButtonTemplate")
		buttons.foodFrameNextButton:SetSize(100,30)
		buttons.foodFrameNextButton:SetPoint("CENTER", 100, -165)
		buttons.foodFrameNextButton:SetText("Next")



		--Misc Frame
		frames.miscFrame = CreateFrame("Frame", "MiscFrame", frames.RaidRConfig)
		frames.miscFrame:SetSize(350,400)
		frames.miscFrame:SetPoint("TOPLEFT")
		frames.miscFrame:Hide()

		--Misc Frame: String for instructions
		fontStrings.miscString = frames.miscFrame:CreateFontString("MiscInstructions")
		fontStrings.miscString:SetFont("Fonts\\FRIZQT__.ttf", 17, "OUTLINE")
		fontStrings.miscString:SetText("Enter the number of each item\nyou expect to use during raid")
		fontStrings.miscString:SetJustifyH("CENTER")
		fontStrings.miscString:SetPoint("CENTER", 0, 150)

		--Misc Frame: Frame for making a border
		frames.miscBorderFrame = CreateFrame("Frame", "MiscBorderFrame", frames.miscFrame)
		frames.miscBorderFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.miscBorderFrame:SetPoint("TOPLEFT", 20, -80)
		frames.miscBorderFrame:SetPoint("BOTTOMRIGHT", -40, 60)

		--Misc Frame: ScrollFrame for misc list
		scrollFrames.miscScrollFrame = CreateFrame("ScrollFrame", "MiscScrollFrame", frames.miscBorderFrame, "UIPanelScrollFrameTemplate")
		scrollFrames.miscScrollFrame:SetPoint("TOPLEFT", 0, -10)
		scrollFrames.miscScrollFrame:SetPoint("BOTTOMRIGHT", 0, 10)
		scrollFrames.miscScrollFrame:SetClipsChildren(true)

		--Misc Frame: Content container for misc ScrollFrame
		frames.miscScrollContent = CreateFrame("Frame", "MiscScrollContent", scrollFrames.miscScrollFrame)
		frames.miscScrollContent:SetSize(290, 110)

		--Spirit Cauldron Frame
		frames.spiritCauldronFrame = CreateFrame("Frame", "spcFrame", frames.miscScrollContent)
		frames.spiritCauldronFrame:SetSize(290, 75)
		frames.spiritCauldronFrame:SetPoint("TOPLEFT", 0, 10)
		--Spirit Cauldron EditBox
		editBoxes.spcEditBox = CreateFrame("EditBox", "editBoxes.spcEditBox", frames.spiritCauldronFrame, "InputBoxTemplate")
		editBoxes.spcEditBox:SetAutoFocus(false)
		editBoxes.spcEditBox:SetSize(25,30)
		editBoxes.spcEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.spcEditBox:SetNumeric(true)
		editBoxes.spcEditBox:SetMaxLetters(3)
		editBoxes.spcEditBox:SetText("0")
		editBoxes.spcEditBox:SetJustifyH("LEFT")
		editBoxes.spcEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.spcEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Spirit Cauldron Item Icon
		buttons.spcItemIcon = CreateFrame("Button", "buttons.spcItemIcon", frames.spiritCauldronFrame)
		buttons.spcItemIcon:SetSize(40,40)
		buttons.spcItemIcon:SetPoint("CENTER", -70, 0)
		buttons.spcItemIcon:SetNormalTexture(GetItemIcon(misc["Spirit Cauldron"]))
		buttons.spcItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(misc["Spirit Cauldron"])
			GameTooltip:Show()
		end)
		buttons.spcItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Spirit Cauldron Name
		fontStrings.spcString = frames.spiritCauldronFrame:CreateFontString("spcName")
		fontStrings.spcString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.spcString:SetText("Spirit Cauldron")
		fontStrings.spcString:SetJustifyH("LEFT")
		fontStrings.spcString:SetPoint("CENTER", 30, 0)

		--Lavish Suramar Feast Frame
		frames.lavishSuramarFeastFrame = CreateFrame("Frame", "lsfFrame", frames.miscScrollContent)
		frames.lavishSuramarFeastFrame:SetSize(290, 75)
		frames.lavishSuramarFeastFrame:SetPoint("TOPLEFT", 0, -45)
		--Lavish Suramar Feast EditBox
		editBoxes.lsfEditBox = CreateFrame("EditBox", "editBoxes.lsfEditBox", frames.lavishSuramarFeastFrame, "InputBoxTemplate")
		editBoxes.lsfEditBox:SetAutoFocus(false)
		editBoxes.lsfEditBox:SetSize(25,30)
		editBoxes.lsfEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.lsfEditBox:SetNumeric(true)
		editBoxes.lsfEditBox:SetMaxLetters(3)
		editBoxes.lsfEditBox:SetText("0")
		editBoxes.lsfEditBox:SetJustifyH("LEFT")
		editBoxes.lsfEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.lsfEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Lavish Suramar Feast Item Icon
		buttons.lsfItemIcon = CreateFrame("Button", "buttons.lsfItemIcon", frames.lavishSuramarFeastFrame)
		buttons.lsfItemIcon:SetSize(40,40)
		buttons.lsfItemIcon:SetPoint("CENTER", -70, 0)
		buttons.lsfItemIcon:SetNormalTexture(GetItemIcon(misc["Lavish Suramar Feast"]))
		buttons.lsfItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(misc["Lavish Suramar Feast"])
			GameTooltip:Show()
		end)
		buttons.lsfItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Lavish Suramar Feast Name
		fontStrings.lsfString = frames.lavishSuramarFeastFrame:CreateFontString("lsfName")
		fontStrings.lsfString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.lsfString:SetText("Lavish Suramar Feast")
		fontStrings.lsfString:SetJustifyH("LEFT")
		fontStrings.lsfString:SetPoint("CENTER", 30, 0)

		--Defiled Augment Rune Frame
		frames.defiledAugmentRuneFrame = CreateFrame("Frame", "darFrame", frames.miscScrollContent)
		frames.defiledAugmentRuneFrame:SetSize(290, 75)
		frames.defiledAugmentRuneFrame:SetPoint("TOPLEFT", 0, -100)
		--Defiled Augment Rune EditBox
		editBoxes.darEditBox = CreateFrame("EditBox", "editBoxes.darEditBox", frames.defiledAugmentRuneFrame, "InputBoxTemplate")
		editBoxes.darEditBox:SetAutoFocus(false)
		editBoxes.darEditBox:SetSize(25,30)
		editBoxes.darEditBox:SetPoint("CENTER", -110, 0)
		editBoxes.darEditBox:SetNumeric(true)
		editBoxes.darEditBox:SetMaxLetters(3)
		editBoxes.darEditBox:SetText("0")
		editBoxes.darEditBox:SetJustifyH("LEFT")
		editBoxes.darEditBox:SetScript("OnEnterPressed",function(s)
			s:ClearFocus()
		end)
		editBoxes.darEditBox:SetScript("OnEditFocusLost",function(s)
			if(s:GetText() == "") then
				s:SetNumber(0)
			end
		end)
		--Defiled Augment Rune Item Icon
		buttons.darItemIcon = CreateFrame("Button", "buttons.darItemIcon", frames.defiledAugmentRuneFrame)
		buttons.darItemIcon:SetSize(40,40)
		buttons.darItemIcon:SetPoint("CENTER", -70, 0)
		buttons.darItemIcon:SetNormalTexture(GetItemIcon(misc["Defiled Augment Rune"]))
		buttons.darItemIcon:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetItemByID(misc["Defiled Augment Rune"])
			GameTooltip:Show()
		end)
		buttons.darItemIcon:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Defiled Augment Rune Name
		fontStrings.darString = frames.defiledAugmentRuneFrame:CreateFontString("darName")
		fontStrings.darString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.darString:SetText("Defiled Augment Rune")
		fontStrings.darString:SetJustifyH("LEFT")
		fontStrings.darString:SetPoint("CENTER", 30, 0)

		scrollFrames.miscScrollFrame:SetScrollChild(frames.miscScrollContent)

		--Misc Frame: Previous Button
		buttons.miscFramePreviousButton = CreateFrame("Button", "MiscFramePreviousButton", frames.miscFrame, "UIPanelButtonTemplate")
		buttons.miscFramePreviousButton:SetSize(100,30)
		buttons.miscFramePreviousButton:SetPoint("CENTER", -100, -165)
		buttons.miscFramePreviousButton:SetText("Previous")

		--Misc Frame: Next Button
		buttons.miscFrameNextButton = CreateFrame("Button", "MiscFrameNextButton", frames.miscFrame, "UIPanelButtonTemplate")
		buttons.miscFrameNextButton:SetSize(100,30)
		buttons.miscFrameNextButton:SetPoint("CENTER", 100, -165)
		buttons.miscFrameNextButton:SetText("Next")



		--RaidTime Frame
		frames.raidTimeFrame = CreateFrame("Frame", "RaidTimeFrame", frames.RaidRConfig)
		frames.raidTimeFrame:SetSize(350,400)
		frames.raidTimeFrame:SetPoint("TOPLEFT")
		frames.raidTimeFrame:Hide()

		--RaidTime Frame: String for instructions
		fontStrings.raidTimeString = frames.raidTimeFrame:CreateFontString("RaidTimeInstructions")
		fontStrings.raidTimeString:SetFont("Fonts\\FRIZQT__.ttf", 17, "OUTLINE")
		fontStrings.raidTimeString:SetText("What days/times do you raid?")
		fontStrings.raidTimeString:SetJustifyH("CENTER")
		fontStrings.raidTimeString:SetPoint("CENTER", 0, 150)

		--RaidTime Frame: Frame for making a border
		frames.raidTimeBorderFrame = CreateFrame("Frame", "RaidTimeBorderFrame", frames.raidTimeFrame)
		frames.raidTimeBorderFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.raidTimeBorderFrame:SetPoint("TOPLEFT", 20, -80)
		frames.raidTimeBorderFrame:SetPoint("BOTTOMRIGHT", -40, 60)

		--RaidTime Frame: ScrollFrame for raidTime list
		scrollFrames.raidTimeScrollFrame = CreateFrame("ScrollFrame", "RaidTimeScrollFrame", frames.raidTimeBorderFrame, "UIPanelScrollFrameTemplate")
		scrollFrames.raidTimeScrollFrame:SetPoint("TOPLEFT", 0, -10)
		scrollFrames.raidTimeScrollFrame:SetPoint("BOTTOMRIGHT", 0, 10)
		scrollFrames.raidTimeScrollFrame:SetClipsChildren(true)

		--RaidTime Frame: Content container for raidTime ScrollFrame
		frames.raidTimeScrollContent = CreateFrame("Frame", "RaidTimeScrollContent", scrollFrames.raidTimeScrollFrame)
		frames.raidTimeScrollContent:SetSize(290, 100)

		--Monday Frame
		frames.mondayFrame = CreateFrame("Frame", "monFrame", frames.raidTimeScrollContent)
		frames.mondayFrame:SetSize(290, 80)
		frames.mondayFrame:SetPoint("TOPLEFT", 0, 10)
		--Monday CheckButton
		checkButtons.mondayCheckButton = CreateFrame("CheckButton", "MondayCheckButton", frames.mondayFrame, "UICheckButtonTemplate")
		checkButtons.mondayCheckButton:SetPoint("CENTER", -110, 10)
		--Monday Name
		fontStrings.monString = frames.mondayFrame:CreateFontString("monName")
		fontStrings.monString:SetFont("Fonts\\FRIZQT__.ttf", 12)
		fontStrings.monString:SetText("Monday")
		fontStrings.monString:SetJustifyH("LEFT")
		fontStrings.monString:SetPoint("CENTER", -70, 11)
		--Monday Dropdowns
		local mondayHour = 1
		local mondayMinute = "00"
		local mondayAMPM = "AM"
		--Monday Hour Dropdown
		dropdowns.mondayHourDropdown = CreateFrame("Frame", "MondayHourDropdown", frames.mondayFrame, "UIDropDownMenuTemplate")
		dropdowns.mondayHourDropdown:SetPoint("CENTER", -95, -20)
		UIDropDownMenu_SetWidth(dropdowns.mondayHourDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.mondayHourDropdown, mondayHour)
		UIDropDownMenu_Initialize(dropdowns.mondayHourDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 1, 12 do
				info.text = i
				info.checked = i == mondayHour
				info.func = self.SetValue
				info.arg1 = i
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.mondayHourDropdown:SetValue(newValue)
			mondayHour = newValue
			UIDropDownMenu_SetText(dropdowns.mondayHourDropdown, mondayHour)
			CloseDropDownMenus()
		end
		--Monday Minute Dropdown
		dropdowns.mondayMinuteDropdown = CreateFrame("Frame", "MondayMinuteDropdown", frames.mondayFrame, "UIDropDownMenuTemplate")
		dropdowns.mondayMinuteDropdown:SetPoint("CENTER", -35, -20)
		UIDropDownMenu_SetWidth(dropdowns.mondayMinuteDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.mondayMinuteDropdown, mondayMinute)
		UIDropDownMenu_Initialize(dropdowns.mondayMinuteDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 0, 11 do
				info.text = string.format("%02d", (i * 5))
				info.checked = string.format("%02d", (i * 5)) == mondayMinute
				info.func = self.SetValue
				info.arg1 = string.format("%02d", (i * 5))
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.mondayMinuteDropdown:SetValue(newValue)
			mondayMinute = newValue
			UIDropDownMenu_SetText(dropdowns.mondayMinuteDropdown, mondayMinute)
			CloseDropDownMenus()
		end
		--Monday AMPM Dropdown
		dropdowns.mondayAMPMDropdown = CreateFrame("Frame", "MondayAMPMDropdown", frames.mondayFrame, "UIDropDownMenuTemplate")
		dropdowns.mondayAMPMDropdown:SetPoint("CENTER", 25, -20)
		UIDropDownMenu_SetWidth(dropdowns.mondayAMPMDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.mondayAMPMDropdown, mondayAMPM)
		UIDropDownMenu_Initialize(dropdowns.mondayAMPMDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			info.text = "AM"
			info.checked = info.text == mondayAMPM
			info.func = self.SetValue
			info.arg1 = "AM"
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "PM"
			info.checked = info.text == mondayAMPM
			info.func = self.SetValue
			info.arg1 = "PM"
			UIDropDownMenu_AddButton(info, level)
		end)
		function dropdowns.mondayAMPMDropdown:SetValue(newValue)
			mondayAMPM = newValue
			UIDropDownMenu_SetText(dropdowns.mondayAMPMDropdown, mondayAMPM)
			CloseDropDownMenus()
		end

		--Tuesday Frame
		frames.tuesdayFrame = CreateFrame("Frame", "tuesFrame", frames.raidTimeScrollContent)
		frames.tuesdayFrame:SetSize(290, 80)
		frames.tuesdayFrame:SetPoint("TOPLEFT", 0, -50)
		--Tuesday CheckButton
		checkButtons.tuesdayCheckButton = CreateFrame("CheckButton", "TuesdayCheckButton", frames.tuesdayFrame, "UICheckButtonTemplate")
		checkButtons.tuesdayCheckButton:SetPoint("CENTER", -110, 10)
		--Tuesday Name
		fontStrings.tuesString = frames.tuesdayFrame:CreateFontString("tuesName")
		fontStrings.tuesString:SetFont("Fonts\\FRIZQT__.ttf", 12)
		fontStrings.tuesString:SetText("Tuesday")
		fontStrings.tuesString:SetJustifyH("LEFT")
		fontStrings.tuesString:SetPoint("CENTER", -70, 11)
		--Tuesday Dropdowns
		local tuesdayHour = 1
		local tuesdayMinute = "00"
		local tuesdayAMPM = "AM"
		--Tuesday Hour Dropdown
		dropdowns.tuesdayHourDropdown = CreateFrame("Frame", "TuesdayHourDropdown", frames.tuesdayFrame, "UIDropDownMenuTemplate")
		dropdowns.tuesdayHourDropdown:SetPoint("CENTER", -95, -20)
		UIDropDownMenu_SetWidth(dropdowns.tuesdayHourDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.tuesdayHourDropdown, tuesdayHour)
		UIDropDownMenu_Initialize(dropdowns.tuesdayHourDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 1, 12 do
				info.text = i
				info.checked = i == tuesdayHour
				info.func = self.SetValue
				info.arg1 = i
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.tuesdayHourDropdown:SetValue(newValue)
			tuesdayHour = newValue
			UIDropDownMenu_SetText(dropdowns.tuesdayHourDropdown, tuesdayHour)
			CloseDropDownMenus()
		end
		--Tuesday Minute Dropdown
		dropdowns.tuesdayMinuteDropdown = CreateFrame("Frame", "TuesdayMinuteDropdown", frames.tuesdayFrame, "UIDropDownMenuTemplate")
		dropdowns.tuesdayMinuteDropdown:SetPoint("CENTER", -35, -20)
		UIDropDownMenu_SetWidth(dropdowns.tuesdayMinuteDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.tuesdayMinuteDropdown, tuesdayMinute)
		UIDropDownMenu_Initialize(dropdowns.tuesdayMinuteDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 0, 11 do
				info.text = string.format("%02d", (i * 5))
				info.checked = string.format("%02d", (i * 5)) == tuesdayMinute
				info.func = self.SetValue
				info.arg1 = string.format("%02d", (i * 5))
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.tuesdayMinuteDropdown:SetValue(newValue)
			tuesdayMinute = newValue
			UIDropDownMenu_SetText(dropdowns.tuesdayMinuteDropdown, tuesdayMinute)
			CloseDropDownMenus()
		end
		--Tuesday AMPM Dropdown
		dropdowns.tuesdayAMPMDropdown = CreateFrame("Frame", "TuesdayAMPMDropdown", frames.tuesdayFrame, "UIDropDownMenuTemplate")
		dropdowns.tuesdayAMPMDropdown:SetPoint("CENTER", 25, -20)
		UIDropDownMenu_SetWidth(dropdowns.tuesdayAMPMDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.tuesdayAMPMDropdown, tuesdayAMPM)
		UIDropDownMenu_Initialize(dropdowns.tuesdayAMPMDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			info.text = "AM"
			info.checked = info.text == tuesdayAMPM
			info.func = self.SetValue
			info.arg1 = "AM"
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "PM"
			info.checked = info.text == tuesdayAMPM
			info.func = self.SetValue
			info.arg1 = "PM"
			UIDropDownMenu_AddButton(info, level)
		end)
		function dropdowns.tuesdayAMPMDropdown:SetValue(newValue)
			tuesdayAMPM = newValue
			UIDropDownMenu_SetText(dropdowns.tuesdayAMPMDropdown, tuesdayAMPM)
			CloseDropDownMenus()
		end

		--Wednesday Frame
		frames.wednesdayFrame = CreateFrame("Frame", "wedFrame", frames.raidTimeScrollContent)
		frames.wednesdayFrame:SetSize(290, 80)
		frames.wednesdayFrame:SetPoint("TOPLEFT", 0, -110)
		--Wednesday CheckButton
		checkButtons.wednesdayCheckButton = CreateFrame("CheckButton", "WednesdayCheckButton", frames.wednesdayFrame, "UICheckButtonTemplate")
		checkButtons.wednesdayCheckButton:SetPoint("CENTER", -110, 10)
		--Wednesday Name
		fontStrings.wedString = frames.wednesdayFrame:CreateFontString("wedName")
		fontStrings.wedString:SetFont("Fonts\\FRIZQT__.ttf", 12)
		fontStrings.wedString:SetText("Wednesday")
		fontStrings.wedString:SetJustifyH("LEFT")
		fontStrings.wedString:SetPoint("CENTER", -60, 11)
		--Wednesday Dropdowns
		local wednesdayHour = 1
		local wednesdayMinute = "00"
		local wednesdayAMPM = "AM"
		--Wednesday Hour Dropdown
		frames.wednesdayHourDropdown = CreateFrame("Frame", "WednesdayHourDropdown", frames.wednesdayFrame, "UIDropDownMenuTemplate")
		frames.wednesdayHourDropdown:SetPoint("CENTER", -95, -20)
		UIDropDownMenu_SetWidth(frames.wednesdayHourDropdown, 40)
		UIDropDownMenu_SetText(frames.wednesdayHourDropdown, wednesdayHour)
		UIDropDownMenu_Initialize(frames.wednesdayHourDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 1, 12 do
				info.text = i
				info.checked = i == wednesdayHour
				info.func = self.SetValue
				info.arg1 = i
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function frames.wednesdayHourDropdown:SetValue(newValue)
			wednesdayHour = newValue
			UIDropDownMenu_SetText(frames.wednesdayHourDropdown, wednesdayHour)
			CloseDropDownMenus()
		end
		--Wednesday Minute Dropdown
		dropdowns.wednesdayMinuteDropdown = CreateFrame("Frame", "WednesdayMinuteDropdown", frames.wednesdayFrame, "UIDropDownMenuTemplate")
		dropdowns.wednesdayMinuteDropdown:SetPoint("CENTER", -35, -20)
		UIDropDownMenu_SetWidth(dropdowns.wednesdayMinuteDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.wednesdayMinuteDropdown, wednesdayMinute)
		UIDropDownMenu_Initialize(dropdowns.wednesdayMinuteDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 0, 11 do
				info.text = string.format("%02d", (i * 5))
				info.checked = string.format("%02d", (i * 5)) == wednesdayMinute
				info.func = self.SetValue
				info.arg1 = string.format("%02d", (i * 5))
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.wednesdayMinuteDropdown:SetValue(newValue)
			wednesdayMinute = newValue
			UIDropDownMenu_SetText(dropdowns.wednesdayMinuteDropdown, wednesdayMinute)
			CloseDropDownMenus()
		end
		--Wednesday AMPM Dropdown
		dropdowns.wednesdayAMPMDropdown = CreateFrame("Frame", "WednesdayAMPMDropdown", frames.wednesdayFrame, "UIDropDownMenuTemplate")
		dropdowns.wednesdayAMPMDropdown:SetPoint("CENTER", 25, -20)
		UIDropDownMenu_SetWidth(dropdowns.wednesdayAMPMDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.wednesdayAMPMDropdown, wednesdayAMPM)
		UIDropDownMenu_Initialize(dropdowns.wednesdayAMPMDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			info.text = "AM"
			info.checked = info.text == wednesdayAMPM
			info.func = self.SetValue
			info.arg1 = "AM"
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "PM"
			info.checked = info.text == wednesdayAMPM
			info.func = self.SetValue
			info.arg1 = "PM"
			UIDropDownMenu_AddButton(info, level)
		end)
		function dropdowns.wednesdayAMPMDropdown:SetValue(newValue)
			wednesdayAMPM = newValue
			UIDropDownMenu_SetText(dropdowns.wednesdayAMPMDropdown, wednesdayAMPM)
			CloseDropDownMenus()
		end

		--Thursday Frame
		frames.thursdayFrame = CreateFrame("Frame", "thursFrame", frames.raidTimeScrollContent)
		frames.thursdayFrame:SetSize(290, 80)
		frames.thursdayFrame:SetPoint("TOPLEFT", 0, -170)
		--Thursday CheckButton
		checkButtons.thursdayCheckButton = CreateFrame("CheckButton", "ThursdayCheckButton", frames.thursdayFrame, "UICheckButtonTemplate")
		checkButtons.thursdayCheckButton:SetPoint("CENTER", -110, 10)
		--Thursday Name
		fontStrings.thursString = frames.thursdayFrame:CreateFontString("thursName")
		fontStrings.thursString:SetFont("Fonts\\FRIZQT__.ttf", 12)
		fontStrings.thursString:SetText("Thursday")
		fontStrings.thursString:SetJustifyH("LEFT")
		fontStrings.thursString:SetPoint("CENTER", -66, 11)
		--Thursday Dropdowns
		local thursdayHour = 1
		local thursdayMinute = "00"
		local thursdayAMPM = "AM"
		--Thursday Hour Dropdown
		dropdowns.thursdayHourDropdown = CreateFrame("Frame", "ThursdayHourDropdown", frames.thursdayFrame, "UIDropDownMenuTemplate")
		dropdowns.thursdayHourDropdown:SetPoint("CENTER", -95, -20)
		UIDropDownMenu_SetWidth(dropdowns.thursdayHourDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.thursdayHourDropdown, thursdayHour)
		UIDropDownMenu_Initialize(dropdowns.thursdayHourDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 1, 12 do
				info.text = i
				info.checked = i == thursdayHour
				info.func = self.SetValue
				info.arg1 = i
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.thursdayHourDropdown:SetValue(newValue)
			thursdayHour = newValue
			UIDropDownMenu_SetText(dropdowns.thursdayHourDropdown, thursdayHour)
			CloseDropDownMenus()
		end
		--Thursday Minute Dropdown
		dropdowns.thursdayMinuteDropdown = CreateFrame("Frame", "ThursdayMinuteDropdown", frames.thursdayFrame, "UIDropDownMenuTemplate")
		dropdowns.thursdayMinuteDropdown:SetPoint("CENTER", -35, -20)
		UIDropDownMenu_SetWidth(dropdowns.thursdayMinuteDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.thursdayMinuteDropdown, thursdayMinute)
		UIDropDownMenu_Initialize(dropdowns.thursdayMinuteDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 0, 11 do
				info.text = string.format("%02d", (i * 5))
				info.checked = string.format("%02d", (i * 5)) == thursdayMinute
				info.func = self.SetValue
				info.arg1 = string.format("%02d", (i * 5))
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.thursdayMinuteDropdown:SetValue(newValue)
			thursdayMinute = newValue
			UIDropDownMenu_SetText(dropdowns.thursdayMinuteDropdown, thursdayMinute)
			CloseDropDownMenus()
		end
		--Thursday AMPM Dropdown
		dropdowns.thursdayAMPMDropdown = CreateFrame("Frame", "ThursdayAMPMDropdown", frames.thursdayFrame, "UIDropDownMenuTemplate")
		dropdowns.thursdayAMPMDropdown:SetPoint("CENTER", 25, -20)
		UIDropDownMenu_SetWidth(dropdowns.thursdayAMPMDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.thursdayAMPMDropdown, thursdayAMPM)
		UIDropDownMenu_Initialize(dropdowns.thursdayAMPMDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			info.text = "AM"
			info.checked = info.text == thursdayAMPM
			info.func = self.SetValue
			info.arg1 = "AM"
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "PM"
			info.checked = info.text == thursdayAMPM
			info.func = self.SetValue
			info.arg1 = "PM"
			UIDropDownMenu_AddButton(info, level)
		end)
		function dropdowns.thursdayAMPMDropdown:SetValue(newValue)
			thursdayAMPM = newValue
			UIDropDownMenu_SetText(dropdowns.thursdayAMPMDropdown, thursdayAMPM)
			CloseDropDownMenus()
		end

		--Friday Frame
		frames.fridayFrame = CreateFrame("Frame", "friFrame", frames.raidTimeScrollContent)
		frames.fridayFrame:SetSize(290, 80)
		frames.fridayFrame:SetPoint("TOPLEFT", 0, -230)
		--Friday CheckButton
		checkButtons.fridayCheckButton = CreateFrame("CheckButton", "FridayCheckButton", frames.fridayFrame, "UICheckButtonTemplate")
		checkButtons.fridayCheckButton:SetPoint("CENTER", -110, 10)
		--Friday Name
		fontStrings.friString = frames.fridayFrame:CreateFontString("friName")
		fontStrings.friString:SetFont("Fonts\\FRIZQT__.ttf", 12)
		fontStrings.friString:SetText("Friday")
		fontStrings.friString:SetJustifyH("LEFT")
		fontStrings.friString:SetPoint("CENTER", -75, 11)
		--Friday Dropdowns
		local fridayHour = 1
		local fridayMinute = "00"
		local fridayAMPM = "AM"
		--Friday Hour Dropdown
		dropdowns.fridayHourDropdown = CreateFrame("Frame", "FridayHourDropdown", frames.fridayFrame, "UIDropDownMenuTemplate")
		dropdowns.fridayHourDropdown:SetPoint("CENTER", -95, -20)
		UIDropDownMenu_SetWidth(dropdowns.fridayHourDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.fridayHourDropdown, fridayHour)
		UIDropDownMenu_Initialize(dropdowns.fridayHourDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 1, 12 do
				info.text = i
				info.checked = i == fridayHour
				info.func = self.SetValue
				info.arg1 = i
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.fridayHourDropdown:SetValue(newValue)
			fridayHour = newValue
			UIDropDownMenu_SetText(dropdowns.fridayHourDropdown, fridayHour)
			CloseDropDownMenus()
		end
		--Friday Minute Dropdown
		dropdowns.fridayMinuteDropdown = CreateFrame("Frame", "FridayMinuteDropdown", frames.fridayFrame, "UIDropDownMenuTemplate")
		dropdowns.fridayMinuteDropdown:SetPoint("CENTER", -35, -20)
		UIDropDownMenu_SetWidth(dropdowns.fridayMinuteDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.fridayMinuteDropdown, fridayMinute)
		UIDropDownMenu_Initialize(dropdowns.fridayMinuteDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 0, 11 do
				info.text = string.format("%02d", (i * 5))
				info.checked = string.format("%02d", (i * 5)) == fridayMinute
				info.func = self.SetValue
				info.arg1 = string.format("%02d", (i * 5))
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.fridayMinuteDropdown:SetValue(newValue)
			fridayMinute = newValue
			UIDropDownMenu_SetText(dropdowns.fridayMinuteDropdown, fridayMinute)
			CloseDropDownMenus()
		end
		--Friday AMPM Dropdown
		dropdowns.fridayAMPMDropdown = CreateFrame("Frame", "FridayAMPMDropdown", frames.fridayFrame, "UIDropDownMenuTemplate")
		dropdowns.fridayAMPMDropdown:SetPoint("CENTER", 25, -20)
		UIDropDownMenu_SetWidth(dropdowns.fridayAMPMDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.fridayAMPMDropdown, fridayAMPM)
		UIDropDownMenu_Initialize(dropdowns.fridayAMPMDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			info.text = "AM"
			info.checked = info.text == fridayAMPM
			info.func = self.SetValue
			info.arg1 = "AM"
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "PM"
			info.checked = info.text == fridayAMPM
			info.func = self.SetValue
			info.arg1 = "PM"
			UIDropDownMenu_AddButton(info, level)
		end)
		function dropdowns.fridayAMPMDropdown:SetValue(newValue)
			fridayAMPM = newValue
			UIDropDownMenu_SetText(dropdowns.fridayAMPMDropdown, fridayAMPM)
			CloseDropDownMenus()
		end

		--Saturday Frame
		frames.saturdayFrame = CreateFrame("Frame", "satFrame", frames.raidTimeScrollContent)
		frames.saturdayFrame:SetSize(290, 80)
		frames.saturdayFrame:SetPoint("TOPLEFT", 0, -290)
		--Saturday CheckButton
		checkButtons.saturdayCheckButton = CreateFrame("CheckButton", "SaturdayCheckButton", frames.saturdayFrame, "UICheckButtonTemplate")
		checkButtons.saturdayCheckButton:SetPoint("CENTER", -110, 10)
		--Saturday Name
		fontStrings.satString = frames.saturdayFrame:CreateFontString("satName")
		fontStrings.satString:SetFont("Fonts\\FRIZQT__.ttf", 12)
		fontStrings.satString:SetText("Saturday")
		fontStrings.satString:SetJustifyH("LEFT")
		fontStrings.satString:SetPoint("CENTER", -67, 11)
		--Saturday Dropdowns
		local saturdayHour = 1
		local saturdayMinute = "00"
		local saturdayAMPM = "AM"
		--Saturday Hour Dropdown
		dropdowns.saturdayHourDropdown = CreateFrame("Frame", "SaturdayHourDropdown", frames.saturdayFrame, "UIDropDownMenuTemplate")
		dropdowns.saturdayHourDropdown:SetPoint("CENTER", -95, -20)
		UIDropDownMenu_SetWidth(dropdowns.saturdayHourDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.saturdayHourDropdown, saturdayHour)
		UIDropDownMenu_Initialize(dropdowns.saturdayHourDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 1, 12 do
				info.text = i
				info.checked = i == saturdayHour
				info.func = self.SetValue
				info.arg1 = i
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.saturdayHourDropdown:SetValue(newValue)
			saturdayHour = newValue
			UIDropDownMenu_SetText(dropdowns.saturdayHourDropdown, saturdayHour)
			CloseDropDownMenus()
		end
		--Saturday Minute Dropdown
		dropdowns.saturdayMinuteDropdown = CreateFrame("Frame", "SaturdayMinuteDropdown", frames.saturdayFrame, "UIDropDownMenuTemplate")
		dropdowns.saturdayMinuteDropdown:SetPoint("CENTER", -35, -20)
		UIDropDownMenu_SetWidth(dropdowns.saturdayMinuteDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.saturdayMinuteDropdown, saturdayMinute)
		UIDropDownMenu_Initialize(dropdowns.saturdayMinuteDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 0, 11 do
				info.text = string.format("%02d", (i * 5))
				info.checked = string.format("%02d", (i * 5)) == saturdayMinute
				info.func = self.SetValue
				info.arg1 = string.format("%02d", (i * 5))
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.saturdayMinuteDropdown:SetValue(newValue)
			saturdayMinute = newValue
			UIDropDownMenu_SetText(dropdowns.saturdayMinuteDropdown, saturdayMinute)
			CloseDropDownMenus()
		end
		--Saturday AMPM Dropdown
		dropdowns.saturdayAMPMDropdown = CreateFrame("Frame", "SaturdayAMPMDropdown", frames.saturdayFrame, "UIDropDownMenuTemplate")
		dropdowns.saturdayAMPMDropdown:SetPoint("CENTER", 25, -20)
		UIDropDownMenu_SetWidth(dropdowns.saturdayAMPMDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.saturdayAMPMDropdown, saturdayAMPM)
		UIDropDownMenu_Initialize(dropdowns.saturdayAMPMDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			info.text = "AM"
			info.checked = info.text == saturdayAMPM
			info.func = self.SetValue
			info.arg1 = "AM"
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "PM"
			info.checked = info.text == saturdayAMPM
			info.func = self.SetValue
			info.arg1 = "PM"
			UIDropDownMenu_AddButton(info, level)
		end)
		function dropdowns.saturdayAMPMDropdown:SetValue(newValue)
			saturdayAMPM = newValue
			UIDropDownMenu_SetText(dropdowns.saturdayAMPMDropdown, saturdayAMPM)
			CloseDropDownMenus()
		end

		--Sunday Frame
		frames.sundayFrame = CreateFrame("Frame", "sunFrame", frames.raidTimeScrollContent)
		frames.sundayFrame:SetSize(290, 80)
		frames.sundayFrame:SetPoint("TOPLEFT", 0, -350)
		--Sunday CheckButton
		checkButtons.sundayCheckButton = CreateFrame("CheckButton", "SundayCheckButton", frames.sundayFrame, "UICheckButtonTemplate")
		checkButtons.sundayCheckButton:SetPoint("CENTER", -110, 10)
		--Sunday Name
		fontStrings.sunString = frames.sundayFrame:CreateFontString("sunName")
		fontStrings.sunString:SetFont("Fonts\\FRIZQT__.ttf", 12)
		fontStrings.sunString:SetText("Sunday")
		fontStrings.sunString:SetJustifyH("LEFT")
		fontStrings.sunString:SetPoint("CENTER", -71, 11)
		--Sunday Dropdowns
		local sundayHour = 1
		local sundayMinute = "00"
		local sundayAMPM = "AM"
		--Sunday Hour Dropdown
		dropdowns.sundayHourDropdown = CreateFrame("Frame", "SundayHourDropdown", frames.sundayFrame, "UIDropDownMenuTemplate")
		dropdowns.sundayHourDropdown:SetPoint("CENTER", -95, -20)
		UIDropDownMenu_SetWidth(dropdowns.sundayHourDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.sundayHourDropdown, sundayHour)
		UIDropDownMenu_Initialize(dropdowns.sundayHourDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 1, 12 do
				info.text = i
				info.checked = i == sundayHour
				info.func = self.SetValue
				info.arg1 = i
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.sundayHourDropdown:SetValue(newValue)
			sundayHour = newValue
			UIDropDownMenu_SetText(dropdowns.sundayHourDropdown, sundayHour)
			CloseDropDownMenus()
		end
		--Sunday Minute Dropdown
		dropdowns.sundayMinuteDropdown = CreateFrame("Frame", "SundayMinuteDropdown", frames.sundayFrame, "UIDropDownMenuTemplate")
		dropdowns.sundayMinuteDropdown:SetPoint("CENTER", -35, -20)
		UIDropDownMenu_SetWidth(dropdowns.sundayMinuteDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.sundayMinuteDropdown, sundayMinute)
		UIDropDownMenu_Initialize(dropdowns.sundayMinuteDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 0, 11 do
				info.text = string.format("%02d", (i * 5))
				info.checked = string.format("%02d", (i * 5)) == sundayMinute
				info.func = self.SetValue
				info.arg1 = string.format("%02d", (i * 5))
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.sundayMinuteDropdown:SetValue(newValue)
			sundayMinute = newValue
			UIDropDownMenu_SetText(dropdowns.sundayMinuteDropdown, sundayMinute)
			CloseDropDownMenus()
		end
		--Sunday AMPM Dropdown
		dropdowns.sundayAMPMDropdown = CreateFrame("Frame", "SundayAMPMDropdown", frames.sundayFrame, "UIDropDownMenuTemplate")
		dropdowns.sundayAMPMDropdown:SetPoint("CENTER", 25, -20)
		UIDropDownMenu_SetWidth(dropdowns.sundayAMPMDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.sundayAMPMDropdown, sundayAMPM)
		UIDropDownMenu_Initialize(dropdowns.sundayAMPMDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			info.text = "AM"
			info.checked = info.text == sundayAMPM
			info.func = self.SetValue
			info.arg1 = "AM"
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "PM"
			info.checked = info.text == sundayAMPM
			info.func = self.SetValue
			info.arg1 = "PM"
			UIDropDownMenu_AddButton(info, level)
		end)
		function dropdowns.sundayAMPMDropdown:SetValue(newValue)
			sundayAMPM = newValue
			UIDropDownMenu_SetText(dropdowns.sundayAMPMDropdown, sundayAMPM)
			CloseDropDownMenus()
		end

		scrollFrames.raidTimeScrollFrame:SetScrollChild(frames.raidTimeScrollContent)

		--RaidTime Frame: Previous Button
		buttons.raidTimeFramePreviousButton = CreateFrame("Button", "RaidTimeFramePreviousButton", frames.raidTimeFrame, "UIPanelButtonTemplate")
		buttons.raidTimeFramePreviousButton:SetSize(100,30)
		buttons.raidTimeFramePreviousButton:SetPoint("CENTER", -100, -165)
		buttons.raidTimeFramePreviousButton:SetText("Previous")

		--RaidTime Frame: Next Button
		buttons.raidTimeFrameNextButton = CreateFrame("Button", "RaidTimeFrameNextButton", frames.raidTimeFrame, "UIPanelButtonTemplate")
		buttons.raidTimeFrameNextButton:SetSize(100,30)
		buttons.raidTimeFrameNextButton:SetPoint("CENTER", 100, -165)
		buttons.raidTimeFrameNextButton:SetText("Next")



		--Options Frame
		frames.optionsFrame = CreateFrame("Frame", "OptionsFrame", frames.RaidRConfig)
		frames.optionsFrame:SetSize(350,400)
		frames.optionsFrame:SetPoint("TOPLEFT")
		frames.optionsFrame:Hide()

		--Options Frame: String for instructions
		fontStrings.optionsString = frames.optionsFrame:CreateFontString("OptionsInstructions")
		fontStrings.optionsString:SetFont("Fonts\\FRIZQT__.ttf", 17, "OUTLINE")
		fontStrings.optionsString:SetText("Let's set up some final options")
		fontStrings.optionsString:SetJustifyH("CENTER")
		fontStrings.optionsString:SetPoint("CENTER", 0, 150)

		--Options Frame: Frame for making a border
		frames.optionsBorderFrame = CreateFrame("Frame", "OptionsBorderFrame", frames.optionsFrame)
		frames.optionsBorderFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.optionsBorderFrame:SetPoint("TOPLEFT", 20, -80)
		frames.optionsBorderFrame:SetPoint("BOTTOMRIGHT", -40, 60)

		--Options Frame: ScrollFrame for options list
		scrollFrames.optionsScrollFrame = CreateFrame("ScrollFrame", "OptionsScrollFrame", frames.optionsBorderFrame, "UIPanelScrollFrameTemplate")
		scrollFrames.optionsScrollFrame:SetPoint("TOPLEFT", 0, -10)
		scrollFrames.optionsScrollFrame:SetPoint("BOTTOMRIGHT", 0, 10)
		scrollFrames.optionsScrollFrame:SetClipsChildren(true)

		--Options Frame: Content container for options ScrollFrame
		frames.optionsScrollContent = CreateFrame("Frame", "OptionsScrollContent", scrollFrames.optionsScrollFrame)
		frames.optionsScrollContent:SetSize(290, 330)

		--Reminder Time Frame
		frames.reminderTimeFrame = CreateFrame("Frame", "rmtFrame", frames.optionsScrollContent)
		frames.reminderTimeFrame:SetSize(290, 75)
		frames.reminderTimeFrame:SetPoint("TOPLEFT", 0, 10)
		--Reminder Time String
		fontStrings.reminderTimeString = frames.reminderTimeFrame:CreateFontString("ReminderTimeString")
		fontStrings.reminderTimeString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.reminderTimeString:SetText("Pre-raid alert: ")
		fontStrings.reminderTimeString:SetJustifyH("LEFT")
		fontStrings.reminderTimeString:SetPoint("CENTER", -85, 0)
		--Reminder Time Dropdown
		local reminderTimeString = "5 minutes"
		local reminderTimeValue = 5
		dropdowns.reminderTimeDropdown = CreateFrame("Frame", "ReminderTimeDropdown", frames.reminderTimeFrame, "UIDropDownMenuTemplate")
		dropdowns.reminderTimeDropdown:SetPoint("CENTER", 5, -3)
		UIDropDownMenu_SetWidth(dropdowns.reminderTimeDropdown, 80)
		UIDropDownMenu_SetText(dropdowns.reminderTimeDropdown, reminderTimeString)
		UIDropDownMenu_Initialize(dropdowns.reminderTimeDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			info.text = "5 minutes"
			info.checked = info.text == reminderTimeString
			info.value = 5
			info.func = self.SetValue
			info.arg1 = info.text
			info.arg2 = info.value
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "10 minutes"
			info.checked = info.text == reminderTimeString
			info.value = 10
			info.func = self.SetValue
			info.arg1 = info.text
			info.arg2 = info.value
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "15 minutes"
			info.checked = info.text == reminderTimeString
			info.value = 15
			info.func = self.SetValue
			info.arg1 = info.text
			info.arg2 = info.value
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "30 minutes"
			info.checked = info.text == reminderTimeString
			info.value = 30
			info.func = self.SetValue
			info.arg1 = info.text
			info.arg2 = info.value
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "45 minutes"
			info.checked = info.text == reminderTimeString
			info.value = 45
			info.func = self.SetValue
			info.arg1 = info.text
			info.arg2 = info.value
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "1 hour"
			info.checked = info.text == reminderTimeString
			info.value = 60
			info.func = self.SetValue
			info.arg1 = info.text
			info.arg2 = info.value
			UIDropDownMenu_AddButton(info, level)
		end)
		function dropdowns.reminderTimeDropdown:SetValue(newString, newValue)
			reminderTimeString = newString
			reminderTimeValue = newValue
			UIDropDownMenu_SetText(dropdowns.reminderTimeDropdown, reminderTimeString)
			CloseDropDownMenus()
		end
		dropdowns.reminderTimeDropdown:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetText("How long before raid you would like\nRaidR to check your consumables")
			GameTooltip:Show()
		end)
		dropdowns.reminderTimeDropdown:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)

		--Bonus Roll Option Frame
		frames.bonusRollOptionFrame = CreateFrame("Frame", "broFrame", frames.optionsScrollContent)
		frames.bonusRollOptionFrame:SetSize(290, 75)
		frames.bonusRollOptionFrame:SetPoint("TOPLEFT", 0, -45)
		--Bonus Roll Option CheckButton
		checkButtons.broCheckButton = CreateFrame("CheckButton", "broCheckButton", frames.bonusRollOptionFrame, "UICheckButtonTemplate")
		checkButtons.broCheckButton:SetPoint("CENTER", -110, -2)
		checkButtons.broCheckButton:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetText("If checked, the reminder window will include a check\nto make sure you bought your Seals this week")
			GameTooltip:Show()
		end)
		checkButtons.broCheckButton:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Bonus Roll Option String
		fontStrings.broString = frames.bonusRollOptionFrame:CreateFontString("broString")
		fontStrings.broString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.broString:SetText("Track bonus rolls")
		fontStrings.broString:SetJustifyH("LEFT")
		fontStrings.broString:SetPoint("CENTER", -50, 0)

		--Play Sound Option Frame
		frames.playSoundOptionFrame = CreateFrame("Frame", "psoFrame", frames.optionsScrollContent)
		frames.playSoundOptionFrame:SetSize(290, 75)
		frames.playSoundOptionFrame:SetPoint("TOPLEFT", 0, -100)
		--Play Sound Option CheckButton
		checkButtons.psoCheckButton = CreateFrame("CheckButton", "psoCheckButton", frames.playSoundOptionFrame, "UICheckButtonTemplate")
		checkButtons.psoCheckButton:SetPoint("CENTER", -110, -2)
		checkButtons.psoCheckButton:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetText("If checked, the reminder window will play a sound alert")
			GameTooltip:Show()
		end)
		checkButtons.psoCheckButton:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Play Sound Option String
		fontStrings.psoString = frames.playSoundOptionFrame:CreateFontString("psoString")
		fontStrings.psoString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.psoString:SetText("Play Sound Alert")
		fontStrings.psoString:SetJustifyH("LEFT")
		fontStrings.psoString:SetPoint("CENTER", -51, 0)

		--Whisper Alert Option Frame
		frames.whisperAlertOptionFrame = CreateFrame("Frame", "waoFrame", frames.optionsScrollContent)
		frames.whisperAlertOptionFrame:SetSize(290, 75)
		frames.whisperAlertOptionFrame:SetPoint("TOPLEFT", 0, -155)
		--Whisper Alert Option CheckButton
		checkButtons.waoCheckButton = CreateFrame("CheckButton", "waoCheckButton", frames.whisperAlertOptionFrame, "UICheckButtonTemplate")
		checkButtons.waoCheckButton:SetPoint("CENTER", -110, -2)
		checkButtons.waoCheckButton:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetText("If checked, RaidR will whisper you if you enter a raid\nwith less than your desired item quantities")
			GameTooltip:Show()
		end)
		checkButtons.waoCheckButton:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Whisper Alert Option String
		fontStrings.waoString = frames.whisperAlertOptionFrame:CreateFontString("waoString")
		fontStrings.waoString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.waoString:SetText("Whisper on Entering Raid")
		fontStrings.waoString:SetJustifyH("LEFT")
		fontStrings.waoString:SetPoint("CENTER", -29, 0)

		scrollFrames.optionsScrollFrame:SetScrollChild(frames.optionsScrollContent)

		--Options Frame: Previous Button
		buttons.optionsFramePreviousButton = CreateFrame("Button", "OptionsFramePreviousButton", frames.optionsFrame, "UIPanelButtonTemplate")
		buttons.optionsFramePreviousButton:SetSize(100,30)
		buttons.optionsFramePreviousButton:SetPoint("CENTER", -100, -165)
		buttons.optionsFramePreviousButton:SetText("Previous")

		--Options Frame: Next Button
		buttons.optionsFrameNextButton = CreateFrame("Button", "OptionsFrameNextButton", frames.optionsFrame, "UIPanelButtonTemplate")
		buttons.optionsFrameNextButton:SetSize(100,30)
		buttons.optionsFrameNextButton:SetPoint("CENTER", 100, -165)
		buttons.optionsFrameNextButton:SetText("Next")



		--Finalize Frame
		frames.finalizeFrame = CreateFrame("Frame", "FinalizeFrame", frames.RaidRConfig)
		frames.finalizeFrame:SetSize(350,400)
		frames.finalizeFrame:SetPoint("TOPLEFT")
		frames.finalizeFrame:Hide()

		--Finalize Frame: Title String
		fontStrings.finalizeTitleString = frames.finalizeFrame:CreateFontString("FinalizeTitle")
		fontStrings.finalizeTitleString:SetFont("Fonts\\FRIZQT__.ttf", 24, "OUTLINE")
		fontStrings.finalizeTitleString:SetText("And that's it!")
		fontStrings.finalizeTitleString:SetJustifyH("CENTER")
		fontStrings.finalizeTitleString:SetPoint("CENTER", 0, 130)

		--Finalize Frame: Instructions String
		fontStrings.finalizeString = frames.finalizeFrame:CreateFontString("Finalize")
		fontStrings.finalizeString:SetFont("Fonts\\FRIZQT__.ttf", 14, "OUTLINE")
		fontStrings.finalizeString:SetText("Click the button below to save your settings,\nor go back to edit your choices")
		fontStrings.finalizeString:SetJustifyH("CENTER")
		fontStrings.finalizeString:SetPoint("CENTER", 0, 90)

		--Finalize Frame: Next Button
		buttons.finalizeFrameNextButton = CreateFrame("Button", "FinalizeFrameNextButton", frames.finalizeFrame, "UIPanelButtonTemplate")
		buttons.finalizeFrameNextButton:SetSize(100,30)
		buttons.finalizeFrameNextButton:SetPoint("CENTER")
		buttons.finalizeFrameNextButton:SetText("Save my Settings")

		--Finalize Frame: Previous Button
		buttons.finalizeFramePreviousButton = CreateFrame("Button", "FinalizeFramePreviousButton", frames.finalizeFrame, "UIPanelButtonTemplate")
		buttons.finalizeFramePreviousButton:SetSize(100,30)
		buttons.finalizeFramePreviousButton:SetPoint("CENTER", -100, -165)
		buttons.finalizeFramePreviousButton:SetText("Previous")



		local function GreetingNext()
			frames.greetingFrame:Hide()
			frames.flaskFrame:Show()
		end
		buttons.greetingFrameNextButton:SetScript("OnClick", function(self, button)
			GreetingNext()
		end)

		local function GreetingSkip()
			frames.RaidRConfig:Hide()
			-- frames = {}
			-- scrollFrames = {}
			-- buttons = {}
			-- dropdowns = {}
			-- fontStrings = {}
			-- editBoxes = {}
			-- checkButtons = {}
			
			raidrSetup = true
		end
		buttons.greetingFrameSkipButton:SetScript("OnClick", function(self, button)
			GreetingSkip()
		end)

		local function FlaskPrevious()
			frames.flaskFrame:Hide()
			frames.greetingFrame:Show()
		end
		buttons.flaskFramePreviousButton:SetScript("OnClick", function(self, button)
			FlaskPrevious()
		end)

		local function FlaskNext()
			frames.flaskFrame:Hide()
			frames.potionFrame:Show()
		end
		buttons.flaskFrameNextButton:SetScript("OnClick", function(self, button)
			FlaskNext()
		end)

		local function PotionPrevious()
			frames.potionFrame:Hide()
			frames.flaskFrame:Show()
		end
		buttons.potionFramePreviousButton:SetScript("OnClick", function(self, button)
			PotionPrevious()
		end)

		local function PotionNext()
			frames.potionFrame:Hide()
			frames.foodFrame:Show()
		end
		buttons.potionFrameNextButton:SetScript("OnClick", function(self, button)
			PotionNext()
		end)

		local function FoodPrevious()
			frames.foodFrame:Hide()
			frames.potionFrame:Show()
		end
		buttons.foodFramePreviousButton:SetScript("OnClick", function(self, button)
			FoodPrevious()
		end)

		local function FoodNext()
			frames.foodFrame:Hide()
			frames.miscFrame:Show()
		end
		buttons.foodFrameNextButton:SetScript("OnClick", function(self, button)
			FoodNext()
		end)

		local function MiscPrevious()
			frames.miscFrame:Hide()
			frames.foodFrame:Show()
		end
		buttons.miscFramePreviousButton:SetScript("OnClick", function(self, button)
			MiscPrevious()
		end)

		local function MiscNext()
			frames.miscFrame:Hide()
			frames.raidTimeFrame:Show()
		end
		buttons.miscFrameNextButton:SetScript("OnClick", function(self, button)
			MiscNext()
		end)

		local function RaidTimePrevious()
			frames.raidTimeFrame:Hide()
			frames.miscFrame:Show()
		end
		buttons.raidTimeFramePreviousButton:SetScript("OnClick", function(self, button)
			RaidTimePrevious()
		end)

		local function RaidTimeNext()
			frames.raidTimeFrame:Hide()
			frames.optionsFrame:Show()
		end
		buttons.raidTimeFrameNextButton:SetScript("OnClick", function(self, button)
			RaidTimeNext()
		end)

		local function OptionsPrevious()
			frames.optionsFrame:Hide()
			frames.raidTimeFrame:Show()
		end
		buttons.optionsFramePreviousButton:SetScript("OnClick", function(self, button)
			OptionsPrevious()
		end)

		local function OptionsNext()
			frames.optionsFrame:Hide()
			frames.finalizeFrame:Show()
		end
		buttons.optionsFrameNextButton:SetScript("OnClick", function(self, button)
			OptionsNext()
		end)

		local function FinalizePrevious()
			frames.finalizeFrame:Hide()
			frames.optionsFrame:Show()
		end
		buttons.finalizeFramePreviousButton:SetScript("OnClick", function(self, button)
			FinalizePrevious()
		end)

		local function FinalizeSave()
			frames.finalizeFrame:Hide()
			raidrFlasks = {}
			raidrFlasks["Flask of the Whispered Pact"] = editBoxes.wpEditBox:GetNumber()
			raidrFlasks["Flask of the Seventh Demon"] = editBoxes.sdEditBox:GetNumber()
			raidrFlasks["Flask of the Countless Armies"] = editBoxes.caEditBox:GetNumber()
			raidrFlasks["Flask of Ten Thousand Scars"] = editBoxes.ttsEditBox:GetNumber()
			
			raidrPotions = {}
			raidrPotions["Ancient Healing Potion"] = editBoxes.anhpEditBox:GetNumber()
			raidrPotions["Ancient Mana Potion"] = editBoxes.ampEditBox:GetNumber()
			raidrPotions["Ancient Rejuvenation Potion"] = editBoxes.ajpEditBox:GetNumber()
			raidrPotions["Potion of Deadly Grace"] = editBoxes.podgEditBox:GetNumber()
			raidrPotions["Potion of the Old War"] = editBoxes.potowEditBox:GetNumber()
			raidrPotions["Unbending Potion"] = editBoxes.upEditBox:GetNumber()
			raidrPotions["Leytorrent Potion"] = editBoxes.lpEditBox:GetNumber()
			raidrPotions["Potion of Prolonged Power"] = editBoxes.poppEditBox:GetNumber()
			raidrPotions["Astral Healing Potion"] = editBoxes.ashpEditBox:GetNumber()
			
			raidrFood = {}
			raidrFood["The Hungry Magister"] = editBoxes.thmEditBox:GetNumber()
			raidrFood["Azshari Salad"] = editBoxes.azsEditBox:GetNumber()
			raidrFood["Nightborne Delicacy Platter"] = editBoxes.ndpEditBox:GetNumber()
			raidrFood["Seed-Battered Fish Plate"] = editBoxes.sbfpEditBox:GetNumber()
			raidrFood["Fishbrul Special"] = editBoxes.fbsEditBox:GetNumber()
			
			raidrMisc = {}
			raidrMisc["Spirit Cauldron"] = editBoxes.spcEditBox:GetNumber()
			raidrMisc["Lavish Suramar Feast"] = editBoxes.lsfEditBox:GetNumber()
			raidrMisc["Defiled Augment Rune"] = editBoxes.darEditBox:GetNumber()
			
			raidrTimes = {}
			mondayTimeTable = {}
			mondayTimeTable["Active"] = checkButtons.mondayCheckButton:GetChecked()
			mondayTimeTable["Hour"] = mondayHour
			mondayTimeTable["Minute"] = tonumber(mondayMinute)
			mondayTimeTable["AMPM"] = mondayAMPM
			local mondayReminder = TimeDiff(mondayHour, tonumber(mondayMinute), mondayAMPM, reminderTimeValue)
			mondayTimeTable["RemH"] = mondayReminder["Hour"]
			mondayTimeTable["RemM"] = mondayReminder["Minute"]
			mondayTimeTable["RemAMPM"] = mondayReminder["AMPM"]
			tuesdayTimeTable = {}
			tuesdayTimeTable["Active"] = checkButtons.tuesdayCheckButton:GetChecked()
			tuesdayTimeTable["Hour"] = tuesdayHour
			tuesdayTimeTable["Minute"] = tonumber(tuesdayMinute)
			tuesdayTimeTable["AMPM"] = tuesdayAMPM
			local tuesdayReminder = TimeDiff(tuesdayHour, tonumber(tuesdayMinute), tuesdayAMPM, reminderTimeValue)
			tuesdayTimeTable["RemH"] = tuesdayReminder["Hour"]
			tuesdayTimeTable["RemM"] = tuesdayReminder["Minute"]
			tuesdayTimeTable["RemAMPM"] = tuesdayReminder["AMPM"]
			wednesdayTimeTable = {}
			wednesdayTimeTable["Active"] = checkButtons.wednesdayCheckButton:GetChecked()
			wednesdayTimeTable["Hour"] = wednesdayHour
			wednesdayTimeTable["Minute"] = tonumber(wednesdayMinute)
			wednesdayTimeTable["AMPM"] = wednesdayAMPM
			local wednesdayReminder = TimeDiff(wednesdayHour, tonumber(wednesdayMinute), wednesdayAMPM, reminderTimeValue)
			wednesdayTimeTable["RemH"] = wednesdayReminder["Hour"]
			wednesdayTimeTable["RemM"] = wednesdayReminder["Minute"]
			wednesdayTimeTable["RemAMPM"] = wednesdayReminder["AMPM"]
			thursdayTimeTable = {}
			thursdayTimeTable["Active"] = checkButtons.thursdayCheckButton:GetChecked()
			thursdayTimeTable["Hour"] = thursdayHour
			thursdayTimeTable["Minute"] = tonumber(thursdayMinute)
			thursdayTimeTable["AMPM"] = thursdayAMPM
			local thursdayReminder = TimeDiff(thursdayHour, tonumber(thursdayMinute), thursdayAMPM, reminderTimeValue)
			thursdayTimeTable["RemH"] = thursdayReminder["Hour"]
			thursdayTimeTable["RemM"] = thursdayReminder["Minute"]
			thursdayTimeTable["RemAMPM"] = thursdayReminder["AMPM"]
			fridayTimeTable = {}
			fridayTimeTable["Active"] = checkButtons.fridayCheckButton:GetChecked()
			fridayTimeTable["Hour"] = fridayHour
			fridayTimeTable["Minute"] = tonumber(fridayMinute)
			fridayTimeTable["AMPM"] = fridayAMPM
			local fridayReminder = TimeDiff(fridayHour, tonumber(fridayMinute), fridayAMPM, reminderTimeValue)
			fridayTimeTable["RemH"] = fridayReminder["Hour"]
			fridayTimeTable["RemM"] = fridayReminder["Minute"]
			fridayTimeTable["RemAMPM"] = fridayReminder["AMPM"]
			saturdayTimeTable = {}
			saturdayTimeTable["Active"] = checkButtons.saturdayCheckButton:GetChecked()
			saturdayTimeTable["Hour"] = saturdayHour
			saturdayTimeTable["Minute"] = tonumber(saturdayMinute)
			saturdayTimeTable["AMPM"] = saturdayAMPM
			local saturdayReminder = TimeDiff(saturdayHour, tonumber(saturdayMinute), saturdayAMPM, reminderTimeValue)
			saturdayTimeTable["RemH"] = saturdayReminder["Hour"]
			saturdayTimeTable["RemM"] = saturdayReminder["Minute"]
			saturdayTimeTable["RemAMPM"] = saturdayReminder["AMPM"]
			sundayTimeTable = {}
			sundayTimeTable["Active"] = checkButtons.sundayCheckButton:GetChecked()
			sundayTimeTable["Hour"] = sundayHour
			sundayTimeTable["Minute"] = tonumber(sundayMinute)
			sundayTimeTable["AMPM"] = sundayAMPM
			local sundayReminder = TimeDiff(sundayHour, tonumber(sundayMinute), sundayAMPM, reminderTimeValue)
			sundayTimeTable["RemH"] = sundayReminder["Hour"]
			sundayTimeTable["RemM"] = sundayReminder["Minute"]
			sundayTimeTable["RemAMPM"] = sundayReminder["AMPM"]
			
			raidrOptions = {}
			raidrOptions["Seals"] = checkButtons.broCheckButton:GetChecked()
			raidrOptions["PlaySound"] = checkButtons.psoCheckButton:GetChecked()
			raidrOptions["OnEnterWhisper"] = checkButtons.waoCheckButton:GetChecked()
			
			raidrTimes["Monday"] = mondayTimeTable
			raidrTimes["Tuesday"] = tuesdayTimeTable
			raidrTimes["Wednesday"] = wednesdayTimeTable
			raidrTimes["Thursday"] = thursdayTimeTable
			raidrTimes["Friday"] = fridayTimeTable
			raidrTimes["Saturday"] = saturdayTimeTable
			raidrTimes["Sunday"] = sundayTimeTable
			
			frames.RaidRConfig:Hide()
			-- frames = {}
			-- scrollFrames = {}
			-- buttons = {}
			-- dropdowns = {}
			-- fontStrings = {}
			-- editBoxes = {}
			-- checkButtons = {}
			
			raidrSetup = true
		end
		buttons.finalizeFrameNextButton:SetScript("OnClick", function(self, button)
			FinalizeSave()
		end)
		
		configCreated = true
	elseif(frames.RaidRReminder:IsVisible() == false and configCreated == true) then
		frames.RaidRConfig:Show()
		frames.greetingFrame:Show()
	end
end

--Runs the reminder window
local function RunReminder()
	if(frames.RaidRConfig:IsVisible() == false and reminderCreated == false and (raidrRemind == true or raidrRemind == nil)) then
		--Setup reminder frame
		frames.RaidRReminder:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.RaidRReminder:SetSize(350, 400)
		frames.RaidRReminder:SetPoint("CENTER", 500, 0)
		frames.RaidRReminder:EnableMouse(true)
		frames.RaidRReminder:SetMovable(true)
		frames.RaidRReminder:RegisterForDrag("LeftButton")
		frames.RaidRReminder:SetScript("OnDragStart", function(self) self:StartMoving() end)
		frames.RaidRReminder:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)
		frames.RaidRReminder:Show()
		
		
		
		--Item Display Frame
		frames.itemDisplayFrame = CreateFrame("Frame", "ItemDisplayFrame", frames.RaidRReminder)
		frames.itemDisplayFrame:SetSize(350,400)
		frames.itemDisplayFrame:SetPoint("TOPLEFT")

		--Item Display Frame: String for instructions 1
		fontStrings.itemDisplayString1 = frames.itemDisplayFrame:CreateFontString("ItemDisplayInstructions")
		fontStrings.itemDisplayString1:SetFont("Fonts\\FRIZQT__.ttf", 20, "OUTLINE")
		fontStrings.itemDisplayString1:SetText("It's almost raid time!")
		fontStrings.itemDisplayString1:SetJustifyH("CENTER")
		fontStrings.itemDisplayString1:SetPoint("CENTER", 0, 160)

		--Item Display Frame: String for instructions 2
		fontStrings.itemDisplayString2 = frames.itemDisplayFrame:CreateFontString("ItemDisplayInstructions")
		fontStrings.itemDisplayString2:SetFont("Fonts\\FRIZQT__.ttf", 15, "OUTLINE")
		fontStrings.itemDisplayString2:SetText("Go grab the consumables you don't have!")
		fontStrings.itemDisplayString2:SetJustifyH("CENTER")
		fontStrings.itemDisplayString2:SetPoint("CENTER", 0, 125)

		--Item Display Frame: Frame for making a border
		frames.itemDisplayBorderFrame = CreateFrame("Frame", "ItemDisplayBorderFrame", frames.itemDisplayFrame)
		frames.itemDisplayBorderFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.itemDisplayBorderFrame:SetPoint("TOPLEFT", 40, -100)
		frames.itemDisplayBorderFrame:SetPoint("BOTTOMRIGHT", -40, 60)

		--Item Display Frame: ScrollFrame for itemDisplay list
		scrollFrames.itemDisplayScrollFrame = CreateFrame("ScrollFrame", "ItemDisplayScrollFrame", frames.itemDisplayBorderFrame, "UIPanelScrollFrameTemplate")
		scrollFrames.itemDisplayScrollFrame:SetPoint("TOPLEFT", 0, -10)
		scrollFrames.itemDisplayScrollFrame:SetPoint("BOTTOMRIGHT", 0, 10)
		scrollFrames.itemDisplayScrollFrame:SetClipsChildren(true)

		--Item Display Frame: Content container for itemDisplay ScrollFrame
		frames.itemDisplayScrollContent = CreateFrame("Frame", "ItemDisplayScrollContent", scrollFrames.itemDisplayScrollFrame)
		
		local fromTop = 10
		
		--Seals Display
		if(raidrOptions["Seals"] == true) then
			local _, __, sealsIcon = GetCurrencyInfo(1273)
			local sealsCount = GetSealsCount()
			--Seals Frame
			frames.sealsFrame = CreateFrame("Frame", "sealsFrame", frames.itemDisplayScrollContent)
			frames.sealsFrame:SetSize(290, 75)
			frames.sealsFrame:SetPoint("TOPLEFT", 0, fromTop)
			--Seals Count FontString
			fontStrings.sealsCountString = frames.sealsFrame:CreateFontString("SealsCountString")
			fontStrings.sealsCountString:SetFont("Fonts\\FRIZQT__.ttf", 10)
			fontStrings.sealsCountString:SetText(sealsCount .. "/" .. 3)
			fontStrings.sealsCountString:SetJustifyH("LEFT")
			fontStrings.sealsCountString:SetPoint("CENTER", -110, 0)
			if(sealsCount < 3) then
				fontStrings.sealsCountString:SetTextColor(1, 0, 0, 1)
			else
				fontStrings.sealsCountString:SetTextColor(0, 1, 0, 1)
			end
			--Seals Item Icon
			buttons.sealsItemIcon = CreateFrame("Button", "buttons.sealsItemIcon", frames.sealsFrame)
			buttons.sealsItemIcon:SetSize(40,40)
			buttons.sealsItemIcon:SetPoint("CENTER", -66, 0)
			buttons.sealsItemIcon:SetNormalTexture(sealsIcon)
			buttons.sealsItemIcon:SetScript("OnEnter", function(self)
				GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
				GameTooltip:ClearLines()
				GameTooltip:SetCurrencyByID(1273)
				GameTooltip:Show()
			end)
			buttons.sealsItemIcon:SetScript("OnLeave", function(self)
				GameTooltip:Hide()
			end)
			--Seals Name
			fontStrings.sealsString = frames.sealsFrame:CreateFontString("sealsName")
			fontStrings.sealsString:SetFont("Fonts\\FRIZQT__.ttf", 10)
			fontStrings.sealsString:SetText("Seal of Broken Fate")
			fontStrings.sealsString:SetJustifyH("LEFT")
			fontStrings.sealsString:SetPoint("CENTER", 30, 0)
			
			fromTop = fromTop - 55
		end
		
		--Flask Display
		for key, value in pairs(raidrFlasks) do
			if(value ~= 0 and value ~= nil) then
				--Entry Frame
				flaskFrameName = "remFrame" .. flasks[key]
				frames[flaskFrameName] = CreateFrame("Frame", flaskFrameName, frames.itemDisplayScrollContent)
				frames[flaskFrameName]:SetSize(290, 75)
				frames[flaskFrameName]:SetPoint("TOPLEFT", 0, fromTop)
				--Entry Count FontString
				flaskCountStringName = "remFontString" .. flasks[key]
				fontStrings[flaskCountStringName] = frames[flaskFrameName]:CreateFontString(flaskCountStringName)
				fontStrings[flaskCountStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[flaskCountStringName]:SetText(GetItemCount(flasks[key]) .. "/" .. value)
				fontStrings[flaskCountStringName]:SetJustifyH("LEFT")
				fontStrings[flaskCountStringName]:SetPoint("CENTER", -110, 0)
				if(GetItemCount(flasks[key]) < value) then
					fontStrings[flaskCountStringName]:SetTextColor(1, 0, 0, 1)
				else
					fontStrings[flaskCountStringName]:SetTextColor(0, 1, 0, 1)
				end
				--Entry Item Icon
				flaskItemIconName = "remItemIcon" .. flasks[key]
				buttons[flaskItemIconName] = CreateFrame("Button", flaskItemIconName, frames[flaskFrameName])
				buttons[flaskItemIconName]:SetSize(40,40)
				buttons[flaskItemIconName]:SetPoint("CENTER", -65, 0)
				buttons[flaskItemIconName]:SetNormalTexture(GetItemIcon(flasks[key]))
				buttons[flaskItemIconName]:SetScript("OnEnter", function(self)
					GameTooltip:SetOwner(self, "ANCHOR_CURSOR")
					GameTooltip:ClearLines()
					GameTooltip:SetItemByID(flasks[key])
					GameTooltip:Show()
				end)
				buttons[flaskItemIconName]:SetScript("OnLeave", function(self)
					GameTooltip:Hide()
				end)
				--Entry Name
				flaskNameStringName = "remNameString" .. flasks[key]
				fontStrings[flaskNameStringName] = frames[flaskFrameName]:CreateFontString(flaskNameStringName)
				fontStrings[flaskNameStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[flaskNameStringName]:SetText(key)
				fontStrings[flaskNameStringName]:SetJustifyH("LEFT")
				fontStrings[flaskNameStringName]:SetPoint("CENTER", 35, 0)
				
				fromTop = fromTop - 55
			end
		end
		
		--Potion Display
		for key, value in pairs(raidrPotions) do
			if(value ~= 0 and value ~= nil) then
				--Entry Frame
				potionFrameName = "remFrame" .. potions[key]
				frames[potionFrameName] = CreateFrame("Frame", potionFrameName, frames.itemDisplayScrollContent)
				frames[potionFrameName]:SetSize(290, 75)
				frames[potionFrameName]:SetPoint("TOPLEFT", 0, fromTop)
				--Entry Count FontString
				potionCountStringName = "remFontString" .. potions[key]
				fontStrings[potionCountStringName] = frames[potionFrameName]:CreateFontString(potionCountStringName)
				fontStrings[potionCountStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[potionCountStringName]:SetText(GetItemCount(potions[key]) .. "/" .. value)
				fontStrings[potionCountStringName]:SetJustifyH("LEFT")
				fontStrings[potionCountStringName]:SetPoint("CENTER", -110, 0)
				if(GetItemCount(potions[key]) < value) then
					fontStrings[potionCountStringName]:SetTextColor(1, 0, 0, 1)
				else
					fontStrings[potionCountStringName]:SetTextColor(0, 1, 0, 1)
				end
				--Entry Item Icon
				potionItemIconName = "remItemIcon" .. potions[key]
				buttons[potionItemIconName] = CreateFrame("Button", potionItemIconName, frames[potionFrameName])
				buttons[potionItemIconName]:SetSize(40,40)
				buttons[potionItemIconName]:SetPoint("CENTER", -65, 0)
				buttons[potionItemIconName]:SetNormalTexture(GetItemIcon(potions[key]))
				buttons[potionItemIconName]:SetScript("OnEnter", function(self)
					GameTooltip:SetOwner(self, "ANCHOR_CURSOR")
					GameTooltip:ClearLines()
					GameTooltip:SetItemByID(potions[key])
					GameTooltip:Show()
				end)
				buttons[potionItemIconName]:SetScript("OnLeave", function(self)
					GameTooltip:Hide()
				end)
				--Entry Name
				potionNameStringName = "remNameString" .. potions[key]
				fontStrings[potionNameStringName] = frames[potionFrameName]:CreateFontString(potionNameStringName)
				fontStrings[potionNameStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[potionNameStringName]:SetText(key)
				fontStrings[potionNameStringName]:SetJustifyH("LEFT")
				fontStrings[potionNameStringName]:SetPoint("CENTER", 35, 0)
				
				fromTop = fromTop - 55
			end
		end
		
		--Food Display
		for key, value in pairs(raidrFood) do
			if(value ~= 0 and value ~= nil) then
				--Entry Frame
				foodFrameName = "remFrame" .. food[key]
				frames[foodFrameName] = CreateFrame("Frame", foodFrameName, frames.itemDisplayScrollContent)
				frames[foodFrameName]:SetSize(290, 75)
				frames[foodFrameName]:SetPoint("TOPLEFT", 0, fromTop)
				--Entry Count FontString
				foodCountStringName = "remFontString" .. food[key]
				fontStrings[foodCountStringName] = frames[foodFrameName]:CreateFontString(foodCountStringName)
				fontStrings[foodCountStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[foodCountStringName]:SetText(GetItemCount(food[key]) .. "/" .. value)
				fontStrings[foodCountStringName]:SetJustifyH("LEFT")
				fontStrings[foodCountStringName]:SetPoint("CENTER", -110, 0)
				if(GetItemCount(food[key]) < value) then
					fontStrings[foodCountStringName]:SetTextColor(1, 0, 0, 1)
				else
					fontStrings[foodCountStringName]:SetTextColor(0, 1, 0, 1)
				end
				--Entry Item Icon
				foodItemIconName = "remItemIcon" .. food[key]
				buttons[foodItemIconName] = CreateFrame("Button", foodItemIconName, frames[foodFrameName])
				buttons[foodItemIconName]:SetSize(40,40)
				buttons[foodItemIconName]:SetPoint("CENTER", -65, 0)
				buttons[foodItemIconName]:SetNormalTexture(GetItemIcon(food[key]))
				buttons[foodItemIconName]:SetScript("OnEnter", function(self)
					GameTooltip:SetOwner(self, "ANCHOR_CURSOR")
					GameTooltip:ClearLines()
					GameTooltip:SetItemByID(food[key])
					GameTooltip:Show()
				end)
				buttons[foodItemIconName]:SetScript("OnLeave", function(self)
					GameTooltip:Hide()
				end)
				--Entry Name
				foodNameStringName = "remNameString" .. food[key]
				fontStrings[foodNameStringName] = frames[foodFrameName]:CreateFontString(foodNameStringName)
				fontStrings[foodNameStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[foodNameStringName]:SetText(key)
				fontStrings[foodNameStringName]:SetJustifyH("LEFT")
				fontStrings[foodNameStringName]:SetPoint("CENTER", 35, 0)
				
				fromTop = fromTop - 55
			end
		end
		
		--Misc Display
		for key, value in pairs(raidrMisc) do
			if(value ~= 0 and value ~= nil) then
				--Entry Frame
				miscFrameName = "remFrame" .. misc[key]
				frames[miscFrameName] = CreateFrame("Frame", miscFrameName, frames.itemDisplayScrollContent)
				frames[miscFrameName]:SetSize(290, 75)
				frames[miscFrameName]:SetPoint("TOPLEFT", 0, fromTop)
				--Entry Count FontString
				miscCountStringName = "remFontString" .. misc[key]
				fontStrings[miscCountStringName] = frames[miscFrameName]:CreateFontString(miscCountStringName)
				fontStrings[miscCountStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[miscCountStringName]:SetText(GetItemCount(misc[key]) .. "/" .. value)
				fontStrings[miscCountStringName]:SetJustifyH("LEFT")
				fontStrings[miscCountStringName]:SetPoint("CENTER", -110, 0)
				if(GetItemCount(misc[key]) < value) then
					fontStrings[miscCountStringName]:SetTextColor(1, 0, 0, 1)
				else
					fontStrings[miscCountStringName]:SetTextColor(0, 1, 0, 1)
				end
				--Entry Item Icon
				miscItemIconName = "remItemIcon" .. misc[key]
				buttons[miscItemIconName] = CreateFrame("Button", miscItemIconName, frames[miscFrameName])
				buttons[miscItemIconName]:SetSize(40,40)
				buttons[miscItemIconName]:SetPoint("CENTER", -65, 0)
				buttons[miscItemIconName]:SetNormalTexture(GetItemIcon(misc[key]))
				buttons[miscItemIconName]:SetScript("OnEnter", function(self)
					GameTooltip:SetOwner(self, "ANCHOR_CURSOR")
					GameTooltip:ClearLines()
					GameTooltip:SetItemByID(misc[key])
					GameTooltip:Show()
				end)
				buttons[miscItemIconName]:SetScript("OnLeave", function(self)
					GameTooltip:Hide()
				end)
				--Entry Name
				miscNameStringName = "remNameString" .. misc[key]
				fontStrings[miscNameStringName] = frames[miscFrameName]:CreateFontString(miscNameStringName)
				fontStrings[miscNameStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[miscNameStringName]:SetText(key)
				fontStrings[miscNameStringName]:SetJustifyH("LEFT")
				fontStrings[miscNameStringName]:SetPoint("CENTER", 35, 0)
				
				fromTop = fromTop - 55
			end
		end
		
		fromTop = (fromTop + 45) * -1
		frames.itemDisplayScrollContent:SetSize(290, fromTop)
		scrollFrames.itemDisplayScrollFrame:SetScrollChild(frames.itemDisplayScrollContent)
		
		--Updates the count of each consumable whenever the inventory changes
		frames.itemDisplayFrame:SetScript("OnEvent", function(self,event)
			if(event == "BAG_UPDATE") then
				for key, value in pairs(raidrFlasks) do
					if(value ~= 0 and value ~= nil) then
						fontStrings[flaskCountStringName]:SetText(GetItemCount(flasks[key]) .. "/" .. value)
						if(GetItemCount(flasks[key]) < value) then
							fontStrings[flaskCountStringName]:SetTextColor(1, 0, 0, 1)
						else
							fontStrings[flaskCountStringName]:SetTextColor(0, 1, 0, 1)
						end
					end
				end
				for key, value in pairs(raidrPotions) do
					if(value ~= 0 and value ~= nil) then
						fontStrings[potionCountStringName]:SetText(GetItemCount(potions[key]) .. "/" .. value)
						if(GetItemCount(potions[key]) < value) then
							fontStrings[potionCountStringName]:SetTextColor(1, 0, 0, 1)
						else
							fontStrings[potionCountStringName]:SetTextColor(0, 1, 0, 1)
						end
					end
				end
				for key, value in pairs(raidrFood) do
					if(value ~= 0 and value ~= nil) then
						fontStrings[foodCountStringName]:SetText(GetItemCount(food[key]) .. "/" .. value)
						if(GetItemCount(food[key]) < value) then
							fontStrings[foodCountStringName]:SetTextColor(1, 0, 0, 1)
						else
							fontStrings[foodCountStringName]:SetTextColor(0, 1, 0, 1)
						end
					end
				end
				for key, value in pairs(raidrMisc) do
					if(value ~= 0 and value ~= nil) then
						fontStrings[miscCountStringName]:SetText(GetItemCount(misc[key]) .. "/" .. value)
						if(GetItemCount(misc[key]) < value) then
							fontStrings[miscCountStringName]:SetTextColor(1, 0, 0, 1)
						else
							fontStrings[miscCountStringName]:SetTextColor(0, 1, 0, 1)
						end
					end
				end
			end
		end)
		frames.itemDisplayFrame:RegisterEvent("BAG_UPDATE")
		
		--Item Display Frame: Do Not Show CheckButton
		checkButtons.itemDisplayCheckButton = CreateFrame("CheckButton", "itemDisplayCheckButton", frames.itemDisplayFrame, "UICheckButtonTemplate")
		checkButtons.itemDisplayCheckButton:SetPoint("CENTER", -130, -165)
		
		--Item Display Frame: Do Not Show FontString
		fontStrings.itemDisplayDoNotShowString = frames.itemDisplayFrame:CreateFontString("itemDisplayDoNotShowName")
		fontStrings.itemDisplayDoNotShowString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.itemDisplayDoNotShowString:SetText("Don't Remind Me Again")
		fontStrings.itemDisplayDoNotShowString:SetJustifyH("LEFT")
		fontStrings.itemDisplayDoNotShowString:SetPoint("CENTER", -50, -165)

		--Item Display Frame: Close Button
		buttons.itemDisplayFrameCloseButton = CreateFrame("Button", "ItemDisplayFrameCloseButton", frames.itemDisplayFrame, "UIPanelButtonTemplate")
		buttons.itemDisplayFrameCloseButton:SetSize(100,30)
		buttons.itemDisplayFrameCloseButton:SetPoint("CENTER", 100, -165)
		buttons.itemDisplayFrameCloseButton:SetText("Close")

		local function ReminderFrameClose()
			if(checkButtons.itemDisplayCheckButton:GetChecked()) then
				raidrRemind = false
			else
				raidrRemind = true
			end
			frames.RaidRReminder:Hide()
		end
		buttons.itemDisplayFrameCloseButton:SetScript("OnClick", function(self, button)
			ReminderFrameClose()
		end)
		
		reminderCreated = true
	elseif(frames.RaidRConfig:IsVisible() == false and reminderCreated == true and (raidrRemind == true or raidrRemind == nil)) then
		frames.RaidRReminder:Show()
	end
end

--Checks if the current time is within range for a reminder to fire
local function ReminderCheck()
	local thisHour, raidHour
	local thisDate = date("*t")
	if(raidrTimes[today]["RemAMPM"] == "PM") then 
		thisHour = 12 + raidrTimes[today]["RemH"]
	else
		thisHour = raidTimes[today]["RemH"]
	end
	if(raidrTimes[today]["AMPM"] == "PM") then 
		raidHour = 12 + raidrTimes[today]["Hour"]
	else
		raidHour = raidTimes[today]["Hour"]
	end
	if((thisDate.hour == thisHour and thisDate.min >= raidrTimes[today]["RemM"]) or (thisDate.hour == raidHour) and thisDate.min < raidrTimes[today]["Minute"]) then
		if(raidrOptions["PlaySound"] and frames.RaidRReminder:IsVisible() == false and raidrRemind == true) then
			PlaySound(8960)
		end
		RunReminder()
	end
end

--Checks to see if there is a raid today
local function RaidDayCheck()
	if(today ~= GetDay()) then
		today = GetDay()
		raidrRemind = true
	end
	for day, dayTable in pairs(raidrTimes) do
		if((day == today) and (dayTable["Active"] == true)) then
			return true
		end
	end
	return false
end

--Runs ReminderCheck() every five minutes
local timer = 300
local function onUpdate(self,elapsed)
    timer = timer + elapsed
    if timer >= 300 then
		timer = 0
		if(RaidDayCheck()) then
			ReminderCheck()
		end
    end
end

--Runs the loop that checks the time and runs a reminder when it's time for one
local function RunReminderLoop()
	local loopFrame = CreateFrame("Frame")
	loopFrame:SetScript("OnUpdate", onUpdate)
end

--Main addon frame
raidrMainFrame = CreateFrame("Frame")
raidrMainFrame:SetScript("OnEvent",function(self,event)
	if(event == "PLAYER_ENTERING_WORLD") then
		if((raidrSetup == nil) or (raidrSetup == false)) then
			RunInitialConfig()
		end
		RunReminderLoop()
		
		local isInstance, instanceType = IsInInstance()
		if(isInstance == true and instanceType == "raid") then
			local haveAll = true
			if(raidrOptions["Seals"] == true) then
				local _, sealsCount = GetCurrencyInfo(1273)
				if(sealsCount < 3) then
					haveAll = false
				end
			end
			for key, value in pairs(raidrFlasks) do
				if(GetItemCount(flasks[key]) < value) then
					haveAll = false
				end
			end
			for key, value in pairs(raidrPotions) do
				if(GetItemCount(potions[key]) < value) then
					haveAll = false
				end
			end
			for key, value in pairs(raidrFood) do
				if(GetItemCount(food[key]) < value) then
					haveAll = false
				end
			end
			for key, value in pairs(raidrMisc) do
				if(GetItemCount(misc[key]) < value) then
					haveAll = false
				end
			end
			if(haveAll == false) then
				PlaySound(3081)
				print("|cffff80ff[RaidR] whispers: Hey! You just entered a raid without all the items you told me you wanted. Type '/raidr scan' to see which ones. (Or type '/raidr notell' and I won't bother you like this again)")
			end
		end
	end
end)
-- raidrMainFrame:RegisterEvent("PLAYER_LOGIN")
raidrMainFrame:RegisterEvent("PLAYER_ENTERING_WORLD")

--Register slash commands
SLASH_RAIDR1 = "/raidr"
SlashCmdList["RAIDR"] = function(msg)
	if(msg == "config") then
		RunInitialConfig()
	elseif(msg == "scan") then
	raidrRemind = true
		RunReminder()
	elseif(msg == "notell") then
		raidrOptions["OnEnterWhisper"] = false
	elseif(msg == "debug") then
		RunReminderLoop()
	elseif(msg == "" or msg == "help") then
		print("|cffff80ff[RaidR] whispers: To run the config, type '/raidr config'\nTo have me check your bags, type '/raidr scan'\nTo disable alerts on entering raid, type '/raidr notell'\nTo make me smile, just keep me installed! :D")
	else
		print("|cffffff00Type '/help' for a listing of a few commands.") --Default UI message for unknown slash commands
	end
end